"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class VentriloHeaderTypedDict(TypedDict):
    cmd: NotRequired[int]
    data_key: NotRequired[int]
    header_key: NotRequired[int]
    id: NotRequired[int]
    total_length: NotRequired[int]


class VentriloHeader(BaseModel):
    cmd: Optional[int] = None

    data_key: Optional[int] = None

    header_key: Optional[int] = None

    id: Optional[int] = None

    total_length: Optional[int] = None
