"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TLSChainTypedDict(TypedDict):
    fingerprint_sha256: NotRequired[str]
    r"""SHA 256 fingerprint of the certificate in the certificate chain."""
    issuer_dn: NotRequired[str]
    r"""Distinguished name of the entity that has signed and issued the certificate."""
    subject_dn: NotRequired[str]
    r"""Distinguished name of the entity that the certificate belongs to."""


class TLSChain(BaseModel):
    fingerprint_sha256: Optional[str] = None
    r"""SHA 256 fingerprint of the certificate in the certificate chain."""

    issuer_dn: Optional[str] = None
    r"""Distinguished name of the entity that has signed and issued the certificate."""

    subject_dn: Optional[str] = None
    r"""Distinguished name of the entity that the certificate belongs to."""
