"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mqtt_connectionackreturn import (
    MqttConnectionAckReturn,
    MqttConnectionAckReturnTypedDict,
)
from .mqtt_subscriptionackreturn import (
    MqttSubscriptionAckReturn,
    MqttSubscriptionAckReturnTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MqttTypedDict(TypedDict):
    connection_ack_raw: NotRequired[str]
    r"""Raw CONNACK response packet"""
    connection_ack_return: NotRequired[MqttConnectionAckReturnTypedDict]
    subscription_ack_return: NotRequired[MqttSubscriptionAckReturnTypedDict]


class Mqtt(BaseModel):
    connection_ack_raw: Optional[str] = None
    r"""Raw CONNACK response packet"""

    connection_ack_return: Optional[MqttConnectionAckReturn] = None

    subscription_ack_return: Optional[MqttSubscriptionAckReturn] = None
