"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class RawCertificateResponseTypedDict(TypedDict):
    certificate_id: str
    pem: str


class RawCertificateResponse(BaseModel):
    certificate_id: str

    pem: str
