"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .lpdmessage import LpdMessage, LpdMessageTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LpdTypedDict(TypedDict):
    jobs: NotRequired[LpdMessageTypedDict]
    long_state: NotRequired[str]
    lpd_message: NotRequired[LpdMessageTypedDict]
    printer: NotRequired[str]
    raw: NotRequired[str]
    short_state: NotRequired[str]
    text: NotRequired[str]


class Lpd(BaseModel):
    jobs: Optional[LpdMessage] = None

    long_state: Optional[str] = None

    lpd_message: Optional[LpdMessage] = None

    printer: Optional[str] = None

    raw: Optional[str] = None

    short_state: Optional[str] = None

    text: Optional[str] = None
