"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pcanywhere_status import PcAnywhereStatus, PcAnywhereStatusTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PcAnywhereTypedDict(TypedDict):
    name: NotRequired[str]
    r"""Workstation Name, with padding bytes removed"""
    nr: NotRequired[str]
    r"""Full 'NR' query response"""
    status: NotRequired[PcAnywhereStatusTypedDict]


class PcAnywhere(BaseModel):
    name: Optional[str] = None
    r"""Workstation Name, with padding bytes removed"""

    nr: Optional[str] = None
    r"""Full 'NR' query response"""

    status: Optional[PcAnywhereStatus] = None
