"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pixelformat import PixelFormat, PixelFormatTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DesktopInfoTypedDict(TypedDict):
    height: NotRequired[int]
    name_len: NotRequired[int]
    pixel_format: NotRequired[PixelFormatTypedDict]
    width: NotRequired[int]


class DesktopInfo(BaseModel):
    height: Optional[int] = None

    name_len: Optional[int] = None

    pixel_format: Optional[PixelFormat] = None

    width: Optional[int] = None
