"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpenDirectoryFileTypedDict(TypedDict):
    extension: NotRequired[str]
    last_modified: NotRequired[str]
    name: NotRequired[str]
    path: NotRequired[str]
    size: NotRequired[int]
    suspicious_score: NotRequired[float]
    type: NotRequired[str]


class OpenDirectoryFile(BaseModel):
    extension: Optional[str] = None

    last_modified: Optional[str] = None

    name: Optional[str] = None

    path: Optional[str] = None

    size: Optional[int] = None

    suspicious_score: Optional[float] = None

    type: Optional[str] = None
