"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusResponseActiveTargetLabelsTypedDict(TypedDict):
    instance: NotRequired[str]
    r"""Instance after relabelling has occurred."""
    job: NotRequired[str]
    r"""Job of target after relabelling has occurred."""


class PrometheusResponseActiveTargetLabels(BaseModel):
    instance: Optional[str] = None
    r"""Instance after relabelling has occurred."""

    job: Optional[str] = None
    r"""Job of target after relabelling has occurred."""
