"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata_nodesettings_node import (
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNode,
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsTypedDict(TypedDict):
    cluster_name: NotRequired[str]
    node: NotRequired[
        ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeTypedDict
    ]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettings(BaseModel):
    cluster_name: Optional[str] = None

    node: Optional[ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNode] = None
