"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assetcertificatelistinputbody import (
    AssetCertificateListInputBody,
    AssetCertificateListInputBodyTypedDict,
)
from .responseenvelopelistcertificateasset import (
    ResponseEnvelopeListCertificateAsset,
    ResponseEnvelopeListCertificateAssetTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3GlobaldataAssetCertificateListPostGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3GlobaldataAssetCertificateListPostGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3GlobaldataAssetCertificateListPostRequestTypedDict(TypedDict):
    asset_certificate_list_input_body: AssetCertificateListInputBodyTypedDict
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3GlobaldataAssetCertificateListPostRequest(BaseModel):
    asset_certificate_list_input_body: Annotated[
        AssetCertificateListInputBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3GlobaldataAssetCertificateListPostResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeListCertificateAssetTypedDict


class V3GlobaldataAssetCertificateListPostResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeListCertificateAsset
