"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpEmbeddedRSACertTypedDict(TypedDict):
    key_length: NotRequired[int]
    magic: NotRequired[int]
    max_bytes_datalen: NotRequired[int]
    modulus: NotRequired[str]
    modulus_bitlen: NotRequired[int]
    public_exponent: NotRequired[int]
    signature: NotRequired[str]


class RdpEmbeddedRSACert(BaseModel):
    key_length: Optional[int] = None

    magic: Optional[int] = None

    max_bytes_datalen: Optional[int] = None

    modulus: Optional[str] = None

    modulus_bitlen: Optional[int] = None

    public_exponent: Optional[int] = None

    signature: Optional[str] = None
