"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ZeromqHandshakeTypedDict(TypedDict):
    raw: NotRequired[str]
    ready: NotRequired[bool]
    socket_type: NotRequired[str]


class ZeromqHandshake(BaseModel):
    raw: Optional[str] = None

    ready: Optional[bool] = None

    socket_type: Optional[str] = None
