"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbHeaderLogTypedDict(TypedDict):
    command: NotRequired[int]
    credits: NotRequired[int]
    flags: NotRequired[int]
    protocol_id: NotRequired[str]
    status: NotRequired[int]


class SmbHeaderLog(BaseModel):
    command: Optional[int] = None

    credits: Optional[int] = None

    flags: Optional[int] = None

    protocol_id: Optional[str] = None

    status: Optional[int] = None
