"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .snmp_engine import SnmpEngine, SnmpEngineTypedDict
from .snmp_interfaces import SnmpInterfaces, SnmpInterfacesTypedDict
from .snmp_physical import SnmpPhysical, SnmpPhysicalTypedDict
from .snmp_system import SnmpSystem, SnmpSystemTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SnmpTypedDict(TypedDict):
    engine: NotRequired[SnmpEngineTypedDict]
    oid_interfaces: NotRequired[SnmpInterfacesTypedDict]
    oid_physical: NotRequired[SnmpPhysicalTypedDict]
    oid_system: NotRequired[SnmpSystemTypedDict]
    versions: NotRequired[Nullable[List[str]]]


class Snmp(BaseModel):
    engine: Optional[SnmpEngine] = None

    oid_interfaces: Optional[SnmpInterfaces] = None

    oid_physical: Optional[SnmpPhysical] = None

    oid_system: Optional[SnmpSystem] = None

    versions: OptionalNullable[List[str]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "engine",
            "oid_interfaces",
            "oid_physical",
            "oid_system",
            "versions",
        ]
        nullable_fields = ["versions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
