"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .valuecountsresponse import ValueCountsResponse, ValueCountsResponseTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeValueCountsResponseTypedDict(TypedDict):
    result: NotRequired[ValueCountsResponseTypedDict]


class ResponseEnvelopeValueCountsResponse(BaseModel):
    result: Optional[ValueCountsResponse] = None
