"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WorkerTypedDict(TypedDict):
    client_id: NotRequired[str]
    fd: NotRequired[str]
    functions: NotRequired[str]
    ip: NotRequired[str]


class Worker(BaseModel):
    client_id: Optional[str] = None

    fd: Optional[str] = None

    functions: Optional[str] = None

    ip: Optional[str] = None
