"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rippleclioresults import RippleClioResults, RippleClioResultsTypedDict
from .rippledpublicresults import RippledPublicResults, RippledPublicResultsTypedDict
from .ripplepeerresults import RipplePeerResults, RipplePeerResultsTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RippleTypedDict(TypedDict):
    ripple_clio: NotRequired[RippleClioResultsTypedDict]
    rippled_peer: NotRequired[RipplePeerResultsTypedDict]
    rippled_public: NotRequired[RippledPublicResultsTypedDict]


class Ripple(BaseModel):
    ripple_clio: Optional[RippleClioResults] = None

    rippled_peer: Optional[RipplePeerResults] = None

    rippled_public: Optional[RippledPublicResults] = None
