"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbSmbVersionsTypedDict(TypedDict):
    major: NotRequired[int]
    r"""Major version"""
    minor: NotRequired[int]
    r"""Minor version"""
    revision: NotRequired[int]
    r"""Protocol Revision"""
    version_string: NotRequired[str]
    r"""Full SMB Version String"""


class SmbSmbVersions(BaseModel):
    major: Optional[int] = None
    r"""Major version"""

    minor: Optional[int] = None
    r"""Minor version"""

    revision: Optional[int] = None
    r"""Protocol Revision"""

    version_string: Optional[str] = None
    r"""Full SMB Version String"""
