"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IvantiAvalancheTypedDict(TypedDict):
    body: NotRequired[str]
    status_code: NotRequired[int]
    version: NotRequired[str]


class IvantiAvalanche(BaseModel):
    body: Optional[str] = None

    status_code: Optional[int] = None

    version: Optional[str] = None
