"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KrpcTypedDict(TypedDict):
    ping_response_id: NotRequired[str]


class Krpc(BaseModel):
    ping_response_id: Optional[str] = None
