"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hostobservationresponse import (
    HostObservationResponse,
    HostObservationResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeHostObservationResponseTypedDict(TypedDict):
    result: NotRequired[HostObservationResponseTypedDict]


class ResponseEnvelopeHostObservationResponse(BaseModel):
    result: Optional[HostObservationResponse] = None
