"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dhcpdiscover_deviceinfo import (
    DhcpdiscoverDeviceInfo,
    DhcpdiscoverDeviceInfoTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DhcpdiscoverResponseParamsTypedDict(TypedDict):
    device_info: NotRequired[DhcpdiscoverDeviceInfoTypedDict]


class DhcpdiscoverResponseParams(BaseModel):
    device_info: Optional[DhcpdiscoverDeviceInfo] = None
