"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CweTypedDict(TypedDict):
    entry: NotRequired[str]
    r"""A unique identifier associated with a class of a software or hardware weakness."""


class Cwe(BaseModel):
    entry: Optional[str] = None
    r"""A unique identifier associated with a class of a software or hardware weakness."""
