"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .webproperty import Webproperty, WebpropertyTypedDict
from censys_platform.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class WebpropertyAssetTypedDict(TypedDict):
    extensions: Dict[str, Any]
    resource: WebpropertyTypedDict


class WebpropertyAsset(BaseModel):
    extensions: Dict[str, Any]

    resource: Webproperty
