"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .l2tp_attributevalues import L2TpAttributeValues, L2TpAttributeValuesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class L2TpStopCcnTypedDict(TypedDict):
    attribute_values: NotRequired[L2TpAttributeValuesTypedDict]


class L2TpStopCcn(BaseModel):
    attribute_values: Optional[L2TpAttributeValues] = None
