"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .noticereference import NoticeReference, NoticeReferenceTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UserNoticeTypedDict(TypedDict):
    explicit_text: NotRequired[str]
    notice_reference: NotRequired[NoticeReferenceTypedDict]


class UserNotice(BaseModel):
    explicit_text: Optional[str] = None

    notice_reference: Optional[NoticeReference] = None
