"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata import (
    ElasticSearchResultsNodeInfoNodesNodeData,
    ElasticSearchResultsNodeInfoNodesNodeDataTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesTypedDict(TypedDict):
    node_data: NotRequired[ElasticSearchResultsNodeInfoNodesNodeDataTypedDict]
    node_name: NotRequired[str]


class ElasticSearchResultsNodeInfoNodes(BaseModel):
    node_data: Optional[ElasticSearchResultsNodeInfoNodesNodeData] = None

    node_name: Optional[str] = None
