"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .l2tp_sccrp import L2TpSccrp, L2TpSccrpTypedDict
from .l2tp_stopccn import L2TpStopCcn, L2TpStopCcnTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class L2TpTypedDict(TypedDict):
    hello_received: NotRequired[bool]
    ordered_messages_raw: NotRequired[Nullable[List[str]]]
    sccn_received: NotRequired[bool]
    sccrp: NotRequired[L2TpSccrpTypedDict]
    sccrp_received: NotRequired[bool]
    sccrq_received: NotRequired[bool]
    stop_sccn: NotRequired[L2TpStopCcnTypedDict]
    stop_sccn_received: NotRequired[bool]
    zlb_received: NotRequired[bool]


class L2Tp(BaseModel):
    hello_received: Optional[bool] = None

    ordered_messages_raw: OptionalNullable[List[str]] = UNSET

    sccn_received: Optional[bool] = None

    sccrp: Optional[L2TpSccrp] = None

    sccrp_received: Optional[bool] = None

    sccrq_received: Optional[bool] = None

    stop_sccn: Optional[L2TpStopCcn] = None

    stop_sccn_received: Optional[bool] = None

    zlb_received: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "hello_received",
            "ordered_messages_raw",
            "sccn_received",
            "sccrp",
            "sccrp_received",
            "sccrq_received",
            "stop_sccn",
            "stop_sccn_received",
            "zlb_received",
        ]
        nullable_fields = ["ordered_messages_raw"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
