"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiSessionHeaderAuthTypeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The raw value of the auth_type"""
    raw: NotRequired[int]
    r"""The raw value of the auth_type"""
    type: NotRequired[int]
    r"""Just the auth type (reserved bits omitted)"""


class IpmiSessionHeaderAuthType(BaseModel):
    name: Optional[str] = None
    r"""The raw value of the auth_type"""

    raw: Optional[int] = None
    r"""The raw value of the auth_type"""

    type: Optional[int] = None
    r"""Just the auth type (reserved bits omitted)"""
