"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rocketmq_clusterinfo import RocketmqClusterInfo, RocketmqClusterInfoTypedDict
from .rocketmq_topiclist import RocketmqTopicList, RocketmqTopicListTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RocketmqTypedDict(TypedDict):
    cluster_info: NotRequired[RocketmqClusterInfoTypedDict]
    topics: NotRequired[RocketmqTopicListTypedDict]
    version: NotRequired[str]


class Rocketmq(BaseModel):
    cluster_info: Optional[RocketmqClusterInfo] = None

    topics: Optional[RocketmqTopicList] = None

    version: Optional[str] = None
