"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .murmurmessage_murmurheader import (
    MurmurMessageMurmurHeader,
    MurmurMessageMurmurHeaderTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MurmurMessageTypedDict(TypedDict):
    body: NotRequired[str]
    header: NotRequired[MurmurMessageMurmurHeaderTypedDict]


class MurmurMessage(BaseModel):
    body: Optional[str] = None

    header: Optional[MurmurMessageMurmurHeader] = None
