"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class PostgresTypedDict(TypedDict):
    protocol_error: NotRequired[Dict[str, str]]
    r"""The error received in response to a StartupMessage with an unexpected protocol version."""
    startup_error: NotRequired[Dict[str, str]]
    r"""The error received in response to a StartupMessage without providing the User field."""
    supported_versions: NotRequired[str]


class Postgres(BaseModel):
    protocol_error: Optional[Dict[str, str]] = None
    r"""The error received in response to a StartupMessage with an unexpected protocol version."""

    startup_error: Optional[Dict[str, str]] = None
    r"""The error received in response to a StartupMessage without providing the User field."""

    supported_versions: Optional[str] = None
