"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .location import Location, LocationTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LocationUpdatedTypedDict(TypedDict):
    location: NotRequired[LocationTypedDict]


class LocationUpdated(BaseModel):
    location: Optional[Location] = None
