"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collection import Collection, CollectionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeCollectionTypedDict(TypedDict):
    result: NotRequired[CollectionTypedDict]


class ResponseEnvelopeCollection(BaseModel):
    result: Optional[Collection] = None
