"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ScreenshotTypedDict(TypedDict):
    extracted_text: NotRequired[str]
    handle: NotRequired[str]
    phash: NotRequired[str]


class Screenshot(BaseModel):
    extracted_text: Optional[str] = None

    handle: Optional[str] = None

    phash: Optional[str] = None
