"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .endpointscan import EndpointScan, EndpointScanTypedDict
from .fielddiff import FieldDiff, FieldDiffTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class EndpointScannedTypedDict(TypedDict):
    diff: NotRequired[Dict[str, FieldDiffTypedDict]]
    scan: NotRequired[EndpointScanTypedDict]


class EndpointScanned(BaseModel):
    diff: Optional[Dict[str, FieldDiff]] = None

    scan: Optional[EndpointScan] = None
