"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoFilesystemTypedDict(TypedDict):
    available: NotRequired[str]
    available_in_bytes: NotRequired[int]
    free: NotRequired[str]
    free_in_bytes: NotRequired[int]
    total: NotRequired[str]
    total_in_bytes: NotRequired[int]


class ElasticSearchResultsNodeInfoClusterCombinedInfoFilesystem(BaseModel):
    available: Optional[str] = None

    available_in_bytes: Optional[int] = None

    free: Optional[str] = None

    free_in_bytes: Optional[int] = None

    total: Optional[str] = None

    total_in_bytes: Optional[int] = None
