"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RedlionCrimsonTypedDict(TypedDict):
    configs_exposed: NotRequired[bool]
    control_engine_status: NotRequired[str]
    current_software_level: NotRequired[str]
    execution_status: NotRequired[str]
    manufacturer: NotRequired[str]
    model: NotRequired[str]


class RedlionCrimson(BaseModel):
    configs_exposed: Optional[bool] = None

    control_engine_status: Optional[str] = None

    current_software_level: Optional[str] = None

    execution_status: Optional[str] = None

    manufacturer: Optional[str] = None

    model: Optional[str] = None
