"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class L2TpAttributeValuesTypedDict(TypedDict):
    error_code: NotRequired[int]
    error_meaning: NotRequired[str]
    error_message: NotRequired[str]
    firmware_revision: NotRequired[int]
    hostname: NotRequired[str]
    protocol_revision: NotRequired[int]
    protocol_version: NotRequired[int]
    result_code: NotRequired[int]
    result_meaning: NotRequired[str]
    vendor_name: NotRequired[str]
    window_size: NotRequired[int]


class L2TpAttributeValues(BaseModel):
    error_code: Optional[int] = None

    error_meaning: Optional[str] = None

    error_message: Optional[str] = None

    firmware_revision: Optional[int] = None

    hostname: Optional[str] = None

    protocol_revision: Optional[int] = None

    protocol_version: Optional[int] = None

    result_code: Optional[int] = None

    result_meaning: Optional[str] = None

    vendor_name: Optional[str] = None

    window_size: Optional[int] = None
