"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Pop3TypedDict(TypedDict):
    start_tls: NotRequired[str]
    r"""The server's response to the STARTTLS command."""


class Pop3(BaseModel):
    start_tls: Optional[str] = None
    r"""The server's response to the STARTTLS command."""
