"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RedlineTypedDict(TypedDict):
    action_response: NotRequired[str]
    settings_response: NotRequired[str]
    transport: NotRequired[str]


class Redline(BaseModel):
    action_response: Optional[str] = None

    settings_response: Optional[str] = None

    transport: Optional[str] = None
