"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SystemCapabilitiesTypedDict(TypedDict):
    discovery_bye: NotRequired[bool]
    discovery_resolve: NotRequired[bool]
    firmware_upgrade: NotRequired[bool]
    http_firmware_upgrade: NotRequired[bool]
    http_support_information: NotRequired[bool]
    http_system_backup: NotRequired[bool]
    http_system_logging: NotRequired[bool]
    remote_discovery: NotRequired[bool]
    storage_configuration: NotRequired[bool]
    system_backup: NotRequired[bool]
    system_logging: NotRequired[bool]


class SystemCapabilities(BaseModel):
    discovery_bye: Optional[bool] = None

    discovery_resolve: Optional[bool] = None

    firmware_upgrade: Optional[bool] = None

    http_firmware_upgrade: Optional[bool] = None

    http_support_information: Optional[bool] = None

    http_system_backup: Optional[bool] = None

    http_system_logging: Optional[bool] = None

    remote_discovery: Optional[bool] = None

    storage_configuration: Optional[bool] = None

    system_backup: Optional[bool] = None

    system_logging: Optional[bool] = None
