"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ipmi_rmcpheader_messageclass import (
    IpmiRMCPHeaderMessageClass,
    IpmiRMCPHeaderMessageClassTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiRMCPHeaderTypedDict(TypedDict):
    message_class: NotRequired[IpmiRMCPHeaderMessageClassTypedDict]
    sequence_number: NotRequired[int]
    r"""Sequence number of this packet in the session."""
    version: NotRequired[int]
    r"""The version. This scanner supports version 6."""


class IpmiRMCPHeader(BaseModel):
    message_class: Optional[IpmiRMCPHeaderMessageClass] = None

    sequence_number: Optional[int] = None
    r"""Sequence number of this packet in the session."""

    version: Optional[int] = None
    r"""The version. This scanner supports version 6."""
