"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ScadaViewTypedDict(TypedDict):
    description: NotRequired[str]
    title: NotRequired[str]


class ScadaView(BaseModel):
    description: Optional[str] = None

    title: Optional[str] = None
