"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MqttConnectionAckReturnTypedDict(TypedDict):
    raw: NotRequired[int]
    r"""Raw connect status value"""
    return_value: NotRequired[str]
    r"""Connection status"""


class MqttConnectionAckReturn(BaseModel):
    raw: Optional[int] = None
    r"""Raw connect status value"""

    return_value: Optional[str] = None
    r"""Connection status"""
