"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificaterevocation_revocationinfo import (
    CertificateRevocationRevocationInfo,
    CertificateRevocationRevocationInfoTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CertificateRevocationTypedDict(TypedDict):
    crl: NotRequired[CertificateRevocationRevocationInfoTypedDict]
    ocsp: NotRequired[CertificateRevocationRevocationInfoTypedDict]


class CertificateRevocation(BaseModel):
    crl: Optional[CertificateRevocationRevocationInfo] = None

    ocsp: Optional[CertificateRevocationRevocationInfo] = None
