"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .fielddiff import FieldDiff, FieldDiffTypedDict
from .servicescan import ServiceScan, ServiceScanTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ServiceScannedTypedDict(TypedDict):
    diff: NotRequired[Dict[str, FieldDiffTypedDict]]
    scan: NotRequired[ServiceScanTypedDict]


class ServiceScanned(BaseModel):
    diff: Optional[Dict[str, FieldDiff]] = None

    scan: Optional[ServiceScan] = None
