"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SSHAlgorithmSelectionDirectionAlgorithmsTypedDict(TypedDict):
    cipher: NotRequired[str]
    compression: NotRequired[str]
    mac: NotRequired[str]


class SSHAlgorithmSelectionDirectionAlgorithms(BaseModel):
    cipher: Optional[str] = None

    compression: Optional[str] = None

    mac: Optional[str] = None
