"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PortmapV3EntryTypedDict(TypedDict):
    description: NotRequired[str]
    network_id: NotRequired[str]
    owner: NotRequired[str]
    shorthand: NotRequired[str]
    universal_address: NotRequired[str]
    version: NotRequired[int]


class PortmapV3Entry(BaseModel):
    description: Optional[str] = None

    network_id: Optional[str] = None

    owner: Optional[str] = None

    shorthand: Optional[str] = None

    universal_address: Optional[str] = None

    version: Optional[int] = None
