"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusResponseDroppedTargetTypedDict(TypedDict):
    address: NotRequired[str]
    r"""Address of target."""
    job: NotRequired[str]
    r"""Job of target."""
    metrics_path: NotRequired[str]
    r"""Path to metrics of target."""
    scheme: NotRequired[str]
    r"""URL scheme."""


class PrometheusResponseDroppedTarget(BaseModel):
    address: Optional[str] = None
    r"""Address of target."""

    job: Optional[str] = None
    r"""Job of target."""

    metrics_path: Optional[str] = None
    r"""Path to metrics of target."""

    scheme: Optional[str] = None
    r"""URL scheme."""
