"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ServerConfigTypedDict(TypedDict):
    allow_html: NotRequired[bool]
    image_message_length: NotRequired[int]
    max_bandwidth: NotRequired[int]
    max_users: NotRequired[int]
    message_length: NotRequired[int]
    recording_allowed: NotRequired[bool]
    welcome_text: NotRequired[str]


class ServerConfig(BaseModel):
    allow_html: Optional[bool] = None

    image_message_length: Optional[int] = None

    max_bandwidth: Optional[int] = None

    max_users: Optional[int] = None

    message_length: Optional[int] = None

    recording_allowed: Optional[bool] = None

    welcome_text: Optional[str] = None
