"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel, Nullable
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class TelnetTypedDict(TypedDict):
    do: NotRequired[Dict[str, Nullable[str]]]
    dont: NotRequired[Dict[str, Nullable[str]]]
    will: NotRequired[Dict[str, Nullable[str]]]
    wont: NotRequired[Dict[str, Nullable[str]]]


class Telnet(BaseModel):
    do: Optional[Dict[str, Nullable[str]]] = None

    dont: Optional[Dict[str, Nullable[str]]] = None

    will: Optional[Dict[str, Nullable[str]]] = None

    wont: Optional[Dict[str, Nullable[str]]] = None
