"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EipIdentityTypedDict(TypedDict):
    device_type: NotRequired[str]
    device_type_code: NotRequired[int]
    product_code: NotRequired[int]
    product_name: NotRequired[str]
    revision: NotRequired[str]
    serial_number: NotRequired[int]
    socket_addr: NotRequired[str]
    socket_port: NotRequired[int]
    state: NotRequired[int]
    status: NotRequired[int]
    vendor_id: NotRequired[str]
    vendor_name: NotRequired[str]


class EipIdentity(BaseModel):
    device_type: Optional[str] = None

    device_type_code: Optional[int] = None

    product_code: Optional[int] = None

    product_name: Optional[str] = None

    revision: Optional[str] = None

    serial_number: Optional[int] = None

    socket_addr: Optional[str] = None

    socket_port: Optional[int] = None

    state: Optional[int] = None

    status: Optional[int] = None

    vendor_id: Optional[str] = None

    vendor_name: Optional[str] = None
