"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata_nodesettings_node_attr import (
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttr,
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeTypedDict(TypedDict):
    attr: NotRequired[
        ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrTypedDict
    ]
    name: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNode(BaseModel):
    attr: Optional[ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttr] = None

    name: Optional[str] = None
