"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dvrip_partitioncapability import (
    DvrIPPartitionCapability,
    DvrIPPartitionCapabilityTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DvrIPTypedDict(TypedDict):
    access_url: NotRequired[str]
    function_capability: NotRequired[str]
    function_list: NotRequired[str]
    hard_drive: NotRequired[str]
    language_support: NotRequired[str]
    network_status: NotRequired[str]
    oem_info: NotRequired[str]
    partition_capability: NotRequired[DvrIPPartitionCapabilityTypedDict]
    serial: NotRequired[str]
    split_screen_capability: NotRequired[str]
    version: NotRequired[str]
    wireless_alarm_capability: NotRequired[str]


class DvrIP(BaseModel):
    access_url: Optional[str] = None

    function_capability: Optional[str] = None

    function_list: Optional[str] = None

    hard_drive: Optional[str] = None

    language_support: Optional[str] = None

    network_status: Optional[str] = None

    oem_info: Optional[str] = None

    partition_capability: Optional[DvrIPPartitionCapability] = None

    serial: Optional[str] = None

    split_screen_capability: Optional[str] = None

    version: Optional[str] = None

    wireless_alarm_capability: Optional[str] = None
