"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaMeasureResponseTypedDict(TypedDict):
    flags: NotRequired[int]
    payload: NotRequired[str]
    receive_seq: NotRequired[int]
    receive_time: NotRequired[int]
    send_seq: NotRequired[int]
    send_time: NotRequired[int]
    type: NotRequired[int]


class CiscoIpslaMeasureResponse(BaseModel):
    flags: Optional[int] = None

    payload: Optional[str] = None

    receive_seq: Optional[int] = None

    receive_time: Optional[int] = None

    send_seq: Optional[int] = None

    send_time: Optional[int] = None

    type: Optional[int] = None
