"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PprofTypedDict(TypedDict):
    allocs: NotRequired[int]
    block: NotRequired[int]
    cmdline: NotRequired[str]
    goroutine: NotRequired[int]
    heap: NotRequired[int]
    mutex: NotRequired[int]
    profile: NotRequired[int]
    threadcreate: NotRequired[int]
    trace: NotRequired[int]


class Pprof(BaseModel):
    allocs: Optional[int] = None

    block: Optional[int] = None

    cmdline: Optional[str] = None

    goroutine: Optional[int] = None

    heap: Optional[int] = None

    mutex: Optional[int] = None

    profile: Optional[int] = None

    threadcreate: Optional[int] = None

    trace: Optional[int] = None
