"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CryptSetupTypedDict(TypedDict):
    client_nonce: NotRequired[str]
    key: NotRequired[str]
    server_nonce: NotRequired[str]


class CryptSetup(BaseModel):
    client_nonce: Optional[str] = None

    key: Optional[str] = None

    server_nonce: Optional[str] = None
