"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PanTiltZoomCapabilitiesTypedDict(TypedDict):
    eflip: NotRequired[bool]
    get_compatible_configurations: NotRequired[bool]
    move_status: NotRequired[bool]
    reverse: NotRequired[bool]
    status_position: NotRequired[bool]


class PanTiltZoomCapabilities(BaseModel):
    eflip: Optional[bool] = None

    get_compatible_configurations: Optional[bool] = None

    move_status: Optional[bool] = None

    reverse: Optional[bool] = None

    status_position: Optional[bool] = None
