"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ja4TScanScanTypedDict(TypedDict):
    fingerprint: NotRequired[str]
    scan_time: NotRequired[str]


class Ja4TScanScan(BaseModel):
    fingerprint: Optional[str] = None

    scan_time: Optional[str] = None
