"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .signedcertificatetimestamp_signature import (
    SignedCertificateTimestampSignature,
    SignedCertificateTimestampSignatureTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SignedCertificateTimestampTypedDict(TypedDict):
    log_id: NotRequired[str]
    signature: NotRequired[SignedCertificateTimestampSignatureTypedDict]
    timestamp: NotRequired[str]
    version: NotRequired[int]


class SignedCertificateTimestamp(BaseModel):
    log_id: Optional[str] = None

    signature: Optional[SignedCertificateTimestampSignature] = None

    timestamp: Optional[str] = None

    version: Optional[int] = None
