"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MoneroP2PResponseHeaderTypedDict(TypedDict):
    command: NotRequired[int]
    expects_response: NotRequired[bool]
    flags: NotRequired[int]
    length: NotRequired[int]
    return_code: NotRequired[int]
    signature: NotRequired[int]
    version: NotRequired[int]


class MoneroP2PResponseHeader(BaseModel):
    command: Optional[int] = None

    expects_response: Optional[bool] = None

    flags: Optional[int] = None

    length: Optional[int] = None

    return_code: Optional[int] = None

    signature: Optional[int] = None

    version: Optional[int] = None
