"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AnalyticsCapabilitiesTypedDict(TypedDict):
    analytics_module_support: NotRequired[bool]
    cell_based_scene_description_supported: NotRequired[bool]
    rule_options_supported: NotRequired[bool]
    rule_support: NotRequired[bool]


class AnalyticsCapabilities(BaseModel):
    analytics_module_support: Optional[bool] = None

    cell_based_scene_description_supported: Optional[bool] = None

    rule_options_supported: Optional[bool] = None

    rule_support: Optional[bool] = None
