"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ContactTypedDict(TypedDict):
    email: NotRequired[str]
    handle: NotRequired[str]
    name: NotRequired[str]


class Contact(BaseModel):
    email: Optional[str] = None

    handle: Optional[str] = None

    name: Optional[str] = None
