"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SnmpEngineTypedDict(TypedDict):
    description: NotRequired[str]
    engine_boots: NotRequired[int]
    engine_time: NotRequired[int]
    format_: NotRequired[str]
    format_data: NotRequired[str]
    organization: NotRequired[str]
    pen: NotRequired[int]
    raw_id: NotRequired[str]
    rfc3411: NotRequired[bool]


class SnmpEngine(BaseModel):
    description: Optional[str] = None

    engine_boots: Optional[int] = None

    engine_time: Optional[int] = None

    format_: Annotated[Optional[str], pydantic.Field(alias="format")] = None

    format_data: Optional[str] = None

    organization: Optional[str] = None

    pen: Optional[int] = None

    raw_id: Optional[str] = None

    rfc3411: Optional[bool] = None
