"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rootstore import RootStore, RootStoreTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ValidationTypedDict(TypedDict):
    apple: NotRequired[RootStoreTypedDict]
    chrome: NotRequired[RootStoreTypedDict]
    microsoft: NotRequired[RootStoreTypedDict]
    nss: NotRequired[RootStoreTypedDict]


class Validation(BaseModel):
    apple: Optional[RootStore] = None

    chrome: Optional[RootStore] = None

    microsoft: Optional[RootStore] = None

    nss: Optional[RootStore] = None
