"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SapRouterClientInfoTypedDict(TypedDict):
    connected: NotRequired[bool]
    connected_on: NotRequired[str]
    id: NotRequired[int]
    routed: NotRequired[bool]
    service: NotRequired[str]
    traced: NotRequired[bool]


class SapRouterClientInfo(BaseModel):
    connected: Optional[bool] = None

    connected_on: Optional[str] = None

    id: Optional[int] = None

    routed: Optional[bool] = None

    service: Optional[str] = None

    traced: Optional[bool] = None
