"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MongodbBuildInfoBuildEnvironmentTypedDict(TypedDict):
    cc: NotRequired[str]
    cc_flags: NotRequired[str]
    cxx: NotRequired[str]
    cxx_flags: NotRequired[str]
    dist_arch: NotRequired[str]
    dist_mod: NotRequired[str]
    link_flags: NotRequired[str]
    target_arch: NotRequired[str]
    target_os: NotRequired[str]


class MongodbBuildInfoBuildEnvironment(BaseModel):
    cc: Optional[str] = None

    cc_flags: Optional[str] = None

    cxx: Optional[str] = None

    cxx_flags: Optional[str] = None

    dist_arch: Optional[str] = None

    dist_mod: Optional[str] = None

    link_flags: Optional[str] = None

    target_arch: Optional[str] = None

    target_os: Optional[str] = None
