"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DhcpdiscoverIPAddressTypedDict(TypedDict):
    default_gateway: NotRequired[str]
    dhcp_enable: NotRequired[bool]
    ip_address: NotRequired[str]
    link_local_address: NotRequired[str]
    subnetmask: NotRequired[str]


class DhcpdiscoverIPAddress(BaseModel):
    default_gateway: Optional[str] = None

    dhcp_enable: Optional[bool] = None

    ip_address: Optional[str] = None

    link_local_address: Optional[str] = None

    subnetmask: Optional[str] = None
