"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AuthenticationErrorDetailTypedDict(TypedDict):
    code: NotRequired[int]
    r"""HTTP status code"""
    message: NotRequired[str]
    r"""Human-readable message describing the error occurrence"""
    reason: NotRequired[str]
    r"""Human-readable explanation of the underlying cause of the error"""
    request: NotRequired[str]
    status: NotRequired[str]
    r"""HTTP status message associated with the error"""


class AuthenticationErrorDetail(BaseModel):
    code: Optional[int] = None
    r"""HTTP status code"""

    message: Optional[str] = None
    r"""Human-readable message describing the error occurrence"""

    reason: Optional[str] = None
    r"""Human-readable explanation of the underlying cause of the error"""

    request: Optional[str] = None

    status: Optional[str] = None
    r"""HTTP status message associated with the error"""
