"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hosttimeline import HostTimeline, HostTimelineTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeHostTimelineTypedDict(TypedDict):
    result: NotRequired[HostTimelineTypedDict]


class ResponseEnvelopeHostTimeline(BaseModel):
    result: Optional[HostTimeline] = None
