"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikePostExTypedDict(TypedDict):
    x64: NotRequired[str]
    x86: NotRequired[str]


class CobaltStrikePostEx(BaseModel):
    x64: Optional[str] = None

    x86: Optional[str] = None
