"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cobaltstrike_config import CobaltStrikeConfig, CobaltStrikeConfigTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikeTypedDict(TypedDict):
    x64: NotRequired[CobaltStrikeConfigTypedDict]
    x86: NotRequired[CobaltStrikeConfigTypedDict]


class CobaltStrike(BaseModel):
    x64: Optional[CobaltStrikeConfig] = None

    x86: Optional[CobaltStrikeConfig] = None
