"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OllamaModelTypedDict(TypedDict):
    digest: NotRequired[str]
    expires_at: NotRequired[str]
    family: NotRequired[str]
    model: NotRequired[str]
    name: NotRequired[str]
    parent_model: NotRequired[str]
    size: NotRequired[int]
    size_vram: NotRequired[int]


class OllamaModel(BaseModel):
    digest: Optional[str] = None

    expires_at: Optional[str] = None

    family: Optional[str] = None

    model: Optional[str] = None

    name: Optional[str] = None

    parent_model: Optional[str] = None

    size: Optional[int] = None

    size_vram: Optional[int] = None
