"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EthereumVersionTypedDict(TypedDict):
    client: NotRequired[str]
    compiler: NotRequired[str]
    platform: NotRequired[str]
    trailing: NotRequired[str]
    version: NotRequired[str]


class EthereumVersion(BaseModel):
    client: Optional[str] = None

    compiler: Optional[str] = None

    platform: Optional[str] = None

    trailing: Optional[str] = None

    version: Optional[str] = None
