"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AuthTypedDict(TypedDict):
    enabled: NotRequired[bool]


class Auth(BaseModel):
    enabled: Optional[bool] = None
