"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CtRecordTypedDict(TypedDict):
    added_to_ct_at: NotRequired[str]
    r"""An RFC-3339-formatted timestamp indicating when the certificate was entered into the CT log."""
    ct_to_censys_at: NotRequired[str]
    r"""An RFC-3339-formated timestamp indicating when the certificate was ingested from the CT log into the Censys dataset."""
    index: NotRequired[int]
    r"""Numerical marker of the certificate's place in the CT log."""


class CtRecord(BaseModel):
    added_to_ct_at: Optional[str] = None
    r"""An RFC-3339-formatted timestamp indicating when the certificate was entered into the CT log."""

    ct_to_censys_at: Optional[str] = None
    r"""An RFC-3339-formated timestamp indicating when the certificate was ingested from the CT log into the Censys dataset."""

    index: Optional[int] = None
    r"""Numerical marker of the certificate's place in the CT log."""
