"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mediaprofile import MediaProfile, MediaProfileTypedDict
from .mediastreaming import MediaStreaming, MediaStreamingTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MediaCapabilitiesTypedDict(TypedDict):
    osd: NotRequired[bool]
    profile: NotRequired[MediaProfileTypedDict]
    rotation: NotRequired[bool]
    snapshot_uri: NotRequired[bool]
    streaming: NotRequired[MediaStreamingTypedDict]
    video_source_mode: NotRequired[bool]


class MediaCapabilities(BaseModel):
    osd: Optional[bool] = None

    profile: Optional[MediaProfile] = None

    rotation: Optional[bool] = None

    snapshot_uri: Optional[bool] = None

    streaming: Optional[MediaStreaming] = None

    video_source_mode: Optional[bool] = None
