"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class QcStatementsMonetaryValueTypedDict(TypedDict):
    amount: NotRequired[int]
    currency: NotRequired[str]
    currency_number: NotRequired[int]
    exponent: NotRequired[int]


class QcStatementsMonetaryValue(BaseModel):
    amount: Optional[int] = None

    currency: Optional[str] = None

    currency_number: Optional[int] = None

    exponent: Optional[int] = None
