"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ElfFileTypedDict(TypedDict):
    class_: NotRequired[str]
    data: NotRequired[str]
    machine: NotRequired[str]
    os_abi: NotRequired[str]
    type: NotRequired[str]


class ElfFile(BaseModel):
    class_: Annotated[Optional[str], pydantic.Field(alias="class")] = None

    data: Optional[str] = None

    machine: Optional[str] = None

    os_abi: Optional[str] = None

    type: Optional[str] = None
