"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpcUaLocalizedTextTypedDict(TypedDict):
    flags: NotRequired[int]
    locale: NotRequired[str]
    text: NotRequired[str]


class OpcUaLocalizedText(BaseModel):
    flags: Optional[int] = None

    locale: Optional[str] = None

    text: Optional[str] = None
