"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ser2NetSerialParametersTypedDict(TypedDict):
    baud_rate: NotRequired[str]
    data_bits: NotRequired[str]
    parity: NotRequired[str]
    stop_bits: NotRequired[str]


class Ser2NetSerialParameters(BaseModel):
    baud_rate: Optional[str] = None

    data_bits: Optional[str] = None

    parity: Optional[str] = None

    stop_bits: Optional[str] = None
