"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .http_repeatedheaders import HTTPRepeatedHeaders, HTTPRepeatedHeadersTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class SsdpTypedDict(TypedDict):
    headers: NotRequired[Dict[str, HTTPRepeatedHeadersTypedDict]]
    upnp_url: NotRequired[str]


class Ssdp(BaseModel):
    headers: Optional[Dict[str, HTTPRepeatedHeaders]] = None

    upnp_url: Optional[str] = None
