"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IppAttributeTypedDict(TypedDict):
    name: NotRequired[str]
    value_tag: NotRequired[int]


class IppAttribute(BaseModel):
    name: Optional[str] = None

    value_tag: Optional[int] = None
