"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ActivemqTypedDict(TypedDict):
    cache_enabled: NotRequired[bool]
    cache_size: NotRequired[int]
    max_frame_size: NotRequired[int]
    max_inactivity_duration: NotRequired[int]
    max_inactivity_duration_initial_delay: NotRequired[int]
    platform_details: NotRequired[str]
    provider_name: NotRequired[str]
    provider_version: NotRequired[str]
    size_prefix_disabled: NotRequired[bool]
    stack_trace_enabled: NotRequired[bool]
    tcp_no_delay_enabled: NotRequired[bool]
    tight_encoding_enabled: NotRequired[bool]


class Activemq(BaseModel):
    cache_enabled: Optional[bool] = None

    cache_size: Optional[int] = None

    max_frame_size: Optional[int] = None

    max_inactivity_duration: Optional[int] = None

    max_inactivity_duration_initial_delay: Optional[int] = None

    platform_details: Optional[str] = None

    provider_name: Optional[str] = None

    provider_version: Optional[str] = None

    size_prefix_disabled: Optional[bool] = None

    stack_trace_enabled: Optional[bool] = None

    tcp_no_delay_enabled: Optional[bool] = None

    tight_encoding_enabled: Optional[bool] = None
