"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from datetime import datetime
from enum import Enum
from typing_extensions import TypedDict


class ChangeType(str, Enum):
    ADDED = "added"
    REMOVED = "removed"


class EventAssetChangeTypedDict(TypedDict):
    change_type: ChangeType
    event_time: datetime
    reason: str


class EventAssetChange(BaseModel):
    change_type: ChangeType

    event_time: datetime

    reason: str
