"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ModbusMEIResponseTypedDict(TypedDict):
    conformity_level: NotRequired[int]
    more_follows: NotRequired[bool]
    objects: NotRequired[Dict[str, str]]


class ModbusMEIResponse(BaseModel):
    conformity_level: Optional[int] = None

    more_follows: Optional[bool] = None

    objects: Optional[Dict[str, str]] = None
