"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pptp_responseinfo import PptpResponseInfo, PptpResponseInfoTypedDict
from .pptp_version import PptpVersion, PptpVersionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PptpTypedDict(TypedDict):
    bearer_message: NotRequired[PptpResponseInfoTypedDict]
    error_message: NotRequired[PptpResponseInfoTypedDict]
    firmware: NotRequired[PptpVersionTypedDict]
    framing_message: NotRequired[PptpResponseInfoTypedDict]
    hostname: NotRequired[str]
    maximum_channels: NotRequired[int]
    protocol: NotRequired[PptpVersionTypedDict]
    result_message: NotRequired[PptpResponseInfoTypedDict]
    vendor: NotRequired[str]


class Pptp(BaseModel):
    bearer_message: Optional[PptpResponseInfo] = None

    error_message: Optional[PptpResponseInfo] = None

    firmware: Optional[PptpVersion] = None

    framing_message: Optional[PptpResponseInfo] = None

    hostname: Optional[str] = None

    maximum_channels: Optional[int] = None

    protocol: Optional[PptpVersion] = None

    result_message: Optional[PptpResponseInfo] = None

    vendor: Optional[str] = None
