"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MongodbIsMasterTypedDict(TypedDict):
    is_master: NotRequired[bool]
    logical_session_timeout_minutes: NotRequired[int]
    max_bson_object_size: NotRequired[int]
    max_message_size_bytes: NotRequired[int]
    max_wire_version: NotRequired[int]
    max_write_batch_size: NotRequired[int]
    min_wire_version: NotRequired[int]
    read_only: NotRequired[bool]


class MongodbIsMaster(BaseModel):
    is_master: Optional[bool] = None

    logical_session_timeout_minutes: Optional[int] = None

    max_bson_object_size: Optional[int] = None

    max_message_size_bytes: Optional[int] = None

    max_wire_version: Optional[int] = None

    max_write_batch_size: Optional[int] = None

    min_wire_version: Optional[int] = None

    read_only: Optional[bool] = None
