"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RdateTypedDict(TypedDict):
    date_: NotRequired[str]


class Rdate(BaseModel):
    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None
