"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EventsCapabilitiesTypedDict(TypedDict):
    max_notification_producers: NotRequired[int]
    max_pull_points: NotRequired[int]
    ws_pausable_subscription_manager_interface_support: NotRequired[bool]
    ws_pull_point_support: NotRequired[bool]
    ws_subscription_policy_support: NotRequired[bool]


class EventsCapabilities(BaseModel):
    max_notification_producers: Optional[int] = None

    max_pull_points: Optional[int] = None

    ws_pausable_subscription_manager_interface_support: Optional[bool] = None

    ws_pull_point_support: Optional[bool] = None

    ws_subscription_policy_support: Optional[bool] = None
