"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ssh_algorithmselection_directionalgorithms import (
    SSHAlgorithmSelectionDirectionAlgorithms,
    SSHAlgorithmSelectionDirectionAlgorithmsTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SSHAlgorithmSelectionTypedDict(TypedDict):
    client_to_server_alg_group: NotRequired[
        SSHAlgorithmSelectionDirectionAlgorithmsTypedDict
    ]
    host_key_algorithm: NotRequired[str]
    kex_algorithm: NotRequired[str]
    server_to_client_alg_group: NotRequired[
        SSHAlgorithmSelectionDirectionAlgorithmsTypedDict
    ]


class SSHAlgorithmSelection(BaseModel):
    client_to_server_alg_group: Optional[SSHAlgorithmSelectionDirectionAlgorithms] = (
        None
    )

    host_key_algorithm: Optional[str] = None

    kex_algorithm: Optional[str] = None

    server_to_client_alg_group: Optional[SSHAlgorithmSelectionDirectionAlgorithms] = (
        None
    )
