"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mssql_preloginoptions_serverversion import (
    MssqlPreloginOptionsServerVersion,
    MssqlPreloginOptionsServerVersionTypedDict,
)
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class MssqlPreloginOptionsTypedDict(TypedDict):
    encrypt_mode: NotRequired[str]
    fed_auth_required: NotRequired[bool]
    instance: NotRequired[str]
    mars: NotRequired[bool]
    nonce: NotRequired[str]
    server_version: NotRequired[MssqlPreloginOptionsServerVersionTypedDict]
    thread_id: NotRequired[int]
    trace_id: NotRequired[str]
    unknown: NotRequired[Dict[str, str]]


class MssqlPreloginOptions(BaseModel):
    encrypt_mode: Optional[str] = None

    fed_auth_required: Optional[bool] = None

    instance: Optional[str] = None

    mars: Optional[bool] = None

    nonce: Optional[str] = None

    server_version: Optional[MssqlPreloginOptionsServerVersion] = None

    thread_id: Optional[int] = None

    trace_id: Optional[str] = None

    unknown: Optional[Dict[str, str]] = None
