"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .floatvalue import FloatValue, FloatValueTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChromecastVolumeTypedDict(TypedDict):
    control_type: NotRequired[str]
    level: NotRequired[float]
    muted: NotRequired[bool]
    step_interval: NotRequired[FloatValueTypedDict]


class ChromecastVolume(BaseModel):
    control_type: Optional[str] = None

    level: Optional[float] = None

    muted: Optional[bool] = None

    step_interval: Optional[FloatValue] = None
