"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GraphqlTypedDict(TypedDict):
    response: NotRequired[str]
    supports_introspection: NotRequired[bool]


class Graphql(BaseModel):
    response: Optional[str] = None

    supports_introspection: Optional[bool] = None
