"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .networkcapabilities import NetworkCapabilities, NetworkCapabilitiesTypedDict
from .securitycapabilities import SecurityCapabilities, SecurityCapabilitiesTypedDict
from .systemcapabilities import SystemCapabilities, SystemCapabilitiesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DeviceCapabilitiesTypedDict(TypedDict):
    network: NotRequired[NetworkCapabilitiesTypedDict]
    security: NotRequired[SecurityCapabilitiesTypedDict]
    system: NotRequired[SystemCapabilitiesTypedDict]


class DeviceCapabilities(BaseModel):
    network: Optional[NetworkCapabilities] = None

    security: Optional[SecurityCapabilities] = None

    system: Optional[SystemCapabilities] = None
