"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ValidityPeriodTypedDict(TypedDict):
    length_seconds: NotRequired[int]
    r"""The duration of the certificate's validity period, in seconds."""
    not_after: NotRequired[str]
    r"""An RFC-3339-formatted timestamp after which the certificate is no longer valid."""
    not_before: NotRequired[str]
    r"""An RFC-3339-formatted timestamp before which the certificate is not valid."""


class ValidityPeriod(BaseModel):
    length_seconds: Optional[int] = None
    r"""The duration of the certificate's validity period, in seconds."""

    not_after: Optional[str] = None
    r"""An RFC-3339-formatted timestamp after which the certificate is no longer valid."""

    not_before: Optional[str] = None
    r"""An RFC-3339-formatted timestamp before which the certificate is not valid."""
