"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hosttimelineevent import HostTimelineEvent, HostTimelineEventTypedDict
from censys_platform.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class HostTimelineEventAssetTypedDict(TypedDict):
    extensions: Dict[str, Any]
    resource: HostTimelineEventTypedDict


class HostTimelineEventAsset(BaseModel):
    extensions: Dict[str, Any]

    resource: HostTimelineEvent
