"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .capabilities import Capabilities, CapabilitiesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OnvifServiceTypedDict(TypedDict):
    capabilities: NotRequired[CapabilitiesTypedDict]
    namespace: NotRequired[str]
    service_version_major: NotRequired[int]
    service_version_minor: NotRequired[int]
    xaddr: NotRequired[str]


class OnvifService(BaseModel):
    capabilities: Optional[Capabilities] = None

    namespace: Optional[str] = None

    service_version_major: Optional[int] = None

    service_version_minor: Optional[int] = None

    xaddr: Optional[str] = None
