"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CrestronCp3TypedDict(TypedDict):
    version_string: NotRequired[str]


class CrestronCp3(BaseModel):
    version_string: Optional[str] = None
