"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PortmapV2EntryTypedDict(TypedDict):
    description: NotRequired[str]
    port: NotRequired[int]
    protocol: NotRequired[str]
    shorthand: NotRequired[str]
    version: NotRequired[int]


class PortmapV2Entry(BaseModel):
    description: Optional[str] = None

    port: Optional[int] = None

    protocol: Optional[str] = None

    shorthand: Optional[str] = None

    version: Optional[int] = None
