"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .listcollectionsresponsev1 import (
    ListCollectionsResponseV1,
    ListCollectionsResponseV1TypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeListCollectionsResponseV1TypedDict(TypedDict):
    result: NotRequired[ListCollectionsResponseV1TypedDict]


class ResponseEnvelopeListCollectionsResponseV1(BaseModel):
    result: Optional[ListCollectionsResponseV1] = None
