"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseenvelopevaluecountsresponse import (
    ResponseEnvelopeValueCountsResponse,
    ResponseEnvelopeValueCountsResponseTypedDict,
)
from .searchvaluecountsinputbody import (
    SearchValueCountsInputBody,
    SearchValueCountsInputBodyTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3ThreathuntingValueCountsGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3ThreathuntingValueCountsGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3ThreathuntingValueCountsRequestTypedDict(TypedDict):
    search_value_counts_input_body: SearchValueCountsInputBodyTypedDict
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3ThreathuntingValueCountsRequest(BaseModel):
    search_value_counts_input_body: Annotated[
        SearchValueCountsInputBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3ThreathuntingValueCountsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeValueCountsResponseTypedDict


class V3ThreathuntingValueCountsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeValueCountsResponse
