"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EtcdVersionTypedDict(TypedDict):
    cluster: NotRequired[str]
    server: NotRequired[str]


class EtcdVersion(BaseModel):
    cluster: Optional[str] = None

    server: Optional[str] = None
