"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TorServiceDescriptorTypedDict(TypedDict):
    algorithm_name: NotRequired[str]
    hash: NotRequired[str]
    hash_bits: NotRequired[int]
    onion: NotRequired[str]


class TorServiceDescriptor(BaseModel):
    algorithm_name: Optional[str] = None

    hash: Optional[str] = None

    hash_bits: Optional[int] = None

    onion: Optional[str] = None
