"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificateasset import CertificateAsset, CertificateAssetTypedDict
from .hostassetwithmatchedservices import (
    HostAssetWithMatchedServices,
    HostAssetWithMatchedServicesTypedDict,
)
from .webpropertyasset import WebpropertyAsset, WebpropertyAssetTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SearchQueryHitTypedDict(TypedDict):
    certificate_v1: NotRequired[CertificateAssetTypedDict]
    host_v1: NotRequired[HostAssetWithMatchedServicesTypedDict]
    webproperty_v1: NotRequired[WebpropertyAssetTypedDict]


class SearchQueryHit(BaseModel):
    certificate_v1: Optional[CertificateAsset] = None

    host_v1: Optional[HostAssetWithMatchedServices] = None

    webproperty_v1: Optional[WebpropertyAsset] = None
