"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaHandshakeHeaderTypedDict(TypedDict):
    length: NotRequired[int]
    seq: NotRequired[int]
    unknown: NotRequired[int]
    version: NotRequired[int]


class CiscoIpslaHandshakeHeader(BaseModel):
    length: Optional[int] = None

    seq: Optional[int] = None

    unknown: Optional[int] = None

    version: Optional[int] = None
