"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesNodeNodeAddressTypedDict(TypedDict):
    address: NotRequired[str]
    r"""Node address, IP/URL."""
    address_type: NotRequired[str]
    r"""Node address type, one of Hostname, ExternalIP or InternalIP."""


class KubernetesNodeNodeAddress(BaseModel):
    address: Optional[str] = None
    r"""Node address, IP/URL."""

    address_type: Optional[str] = None
    r"""Node address type, one of Hostname, ExternalIP or InternalIP."""
