"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UserTypedDict(TypedDict):
    auth_key_id: NotRequired[str]
    steamid: NotRequired[str]


class User(BaseModel):
    auth_key_id: Optional[str] = None

    steamid: Optional[str] = None
