"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .webpropertyasset import WebpropertyAsset, WebpropertyAssetTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeWebpropertyAssetTypedDict(TypedDict):
    result: NotRequired[WebpropertyAssetTypedDict]


class ResponseEnvelopeWebpropertyAsset(BaseModel):
    result: Optional[WebpropertyAsset] = None
