"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UpnpServiceTypedDict(TypedDict):
    control_url: NotRequired[str]
    event_sub_url: NotRequired[str]
    scpd_url: NotRequired[str]
    service_id: NotRequired[str]
    service_type: NotRequired[str]


class UpnpService(BaseModel):
    control_url: Optional[str] = None

    event_sub_url: Optional[str] = None

    scpd_url: Optional[str] = None

    service_id: Optional[str] = None

    service_type: Optional[str] = None
