"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CrudUpdateInputBodyTypedDict(TypedDict):
    name: str
    r"""name of the collection"""
    query: str
    r"""query string to search upon to build the collection"""
    description: NotRequired[str]
    r"""description of the collection"""


class CrudUpdateInputBody(BaseModel):
    name: str
    r"""name of the collection"""

    query: str
    r"""query string to search upon to build the collection"""

    description: Optional[str] = None
    r"""description of the collection"""
