"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TacacsPlusTypedDict(TypedDict):
    data_length: NotRequired[int]
    flags: NotRequired[int]
    obfuscated: NotRequired[str]
    seq_num: NotRequired[int]
    session_id: NotRequired[int]
    type: NotRequired[int]
    version: NotRequired[int]


class TacacsPlus(BaseModel):
    data_length: Optional[int] = None

    flags: Optional[int] = None

    obfuscated: Optional[str] = None

    seq_num: Optional[int] = None

    session_id: Optional[int] = None

    type: Optional[int] = None

    version: Optional[int] = None
