"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mongodb_buildinfo_buildenvironment import (
    MongodbBuildInfoBuildEnvironment,
    MongodbBuildInfoBuildEnvironmentTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MongodbBuildInfoTypedDict(TypedDict):
    build_environment: NotRequired[MongodbBuildInfoBuildEnvironmentTypedDict]
    git_version: NotRequired[str]
    r"""Version of mongodb server"""
    version: NotRequired[str]
    r"""Version of mongodb server"""


class MongodbBuildInfo(BaseModel):
    build_environment: Optional[MongodbBuildInfoBuildEnvironment] = None

    git_version: Optional[str] = None
    r"""Version of mongodb server"""

    version: Optional[str] = None
    r"""Version of mongodb server"""
