"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IpmiRMCPHeaderMessageClassTypedDict(TypedDict):
    class_: NotRequired[int]
    r"""Just the class part of the byte (lower 5 bits of raw)"""
    is_ack: NotRequired[bool]
    r"""True if the message is an acknowledgment to a previous message."""
    name: NotRequired[str]
    r"""The human-readable name of the message class"""
    raw: NotRequired[int]
    r"""The raw message class byte."""


class IpmiRMCPHeaderMessageClass(BaseModel):
    class_: Annotated[Optional[int], pydantic.Field(alias="class")] = None
    r"""Just the class part of the byte (lower 5 bits of raw)"""

    is_ack: Optional[bool] = None
    r"""True if the message is an acknowledgment to a previous message."""

    name: Optional[str] = None
    r"""The human-readable name of the message class"""

    raw: Optional[int] = None
    r"""The raw message class byte."""
