"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .searchqueryresponse import SearchQueryResponse, SearchQueryResponseTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeSearchQueryResponseTypedDict(TypedDict):
    result: NotRequired[SearchQueryResponseTypedDict]


class ResponseEnvelopeSearchQueryResponse(BaseModel):
    result: Optional[SearchQueryResponse] = None
