"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class FieldValuePairTypedDict(TypedDict):
    field: str
    r"""The field to match"""
    value: str
    r"""The value to match"""


class FieldValuePair(BaseModel):
    field: str
    r"""The field to match"""

    value: str
    r"""The value to match"""
