"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .saprouter_routerinfo import SapRouterRouterInfo, SapRouterRouterInfoTypedDict
from .saprouter_routerversioninfo import (
    SapRouterRouterVersionInfo,
    SapRouterRouterVersionInfoTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SapRouterTypedDict(TypedDict):
    router_info: NotRequired[SapRouterRouterInfoTypedDict]
    router_version_info: NotRequired[SapRouterRouterVersionInfoTypedDict]


class SapRouter(BaseModel):
    router_info: Optional[SapRouterRouterInfo] = None

    router_version_info: Optional[SapRouterRouterVersionInfo] = None
