"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .autonomoussystem import AutonomousSystem, AutonomousSystemTypedDict
from .fielddiff import FieldDiff, FieldDiffTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class RouteUpdatedTypedDict(TypedDict):
    diff: NotRequired[Dict[str, FieldDiffTypedDict]]
    route: NotRequired[AutonomousSystemTypedDict]


class RouteUpdated(BaseModel):
    diff: Optional[Dict[str, FieldDiff]] = None

    route: Optional[AutonomousSystem] = None
