"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pgbouncer_startupcapabilities import (
    PgbouncerStartupCapabilities,
    PgbouncerStartupCapabilitiesTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PgbouncerTypedDict(TypedDict):
    startup_capabilities: NotRequired[PgbouncerStartupCapabilitiesTypedDict]


class Pgbouncer(BaseModel):
    startup_capabilities: Optional[PgbouncerStartupCapabilities] = None
