"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SocksTypedDict(TypedDict):
    no_authentication_required: NotRequired[bool]
    preferred_authentication: NotRequired[str]
    preferred_authentication_value: NotRequired[int]
    socks_version: NotRequired[int]


class Socks(BaseModel):
    no_authentication_required: Optional[bool] = None

    preferred_authentication: Optional[str] = None

    preferred_authentication_value: Optional[int] = None

    socks_version: Optional[int] = None
