"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_systeminfo_ver import (
    ElasticSearchSystemInfoVer,
    ElasticSearchSystemInfoVerTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchSystemInfoTypedDict(TypedDict):
    cluster_uuid: NotRequired[str]
    name: NotRequired[str]
    tagline: NotRequired[str]
    version: NotRequired[ElasticSearchSystemInfoVerTypedDict]


class ElasticSearchSystemInfo(BaseModel):
    cluster_uuid: Optional[str] = None

    name: Optional[str] = None

    tagline: Optional[str] = None

    version: Optional[ElasticSearchSystemInfoVer] = None
