"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RecordingCapabilitiesTypedDict(TypedDict):
    dynamic_recordings: NotRequired[bool]
    dynamic_tracks: NotRequired[bool]
    encoding: NotRequired[str]
    max_rate: NotRequired[int]
    max_recordings: NotRequired[int]
    max_recordings_job: NotRequired[int]
    max_total_rate: NotRequired[int]
    options: NotRequired[bool]


class RecordingCapabilities(BaseModel):
    dynamic_recordings: Optional[bool] = None

    dynamic_tracks: Optional[bool] = None

    encoding: Optional[str] = None

    max_rate: Optional[int] = None

    max_recordings: Optional[int] = None

    max_recordings_job: Optional[int] = None

    max_total_rate: Optional[int] = None

    options: Optional[bool] = None
