"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesEndpointSubsetEndpointAddressTypedDict(TypedDict):
    hostname: NotRequired[str]
    ip: NotRequired[str]
    node_name: NotRequired[str]


class KubernetesEndpointSubsetEndpointAddress(BaseModel):
    hostname: Optional[str] = None

    ip: Optional[str] = None

    node_name: Optional[str] = None
