"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiCommandPayloadPackedNetFnLogicalUnitNumberTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The human-readable name of the LUN"""
    raw: NotRequired[int]
    r"""The value of the LUN (3 bits)"""


class IpmiCommandPayloadPackedNetFnLogicalUnitNumber(BaseModel):
    name: Optional[str] = None
    r"""The human-readable name of the LUN"""

    raw: Optional[int] = None
    r"""The value of the LUN (3 bits)"""
