"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MediaStreamingTypedDict(TypedDict):
    non_aggregate_control: NotRequired[bool]
    rtp_multicast: NotRequired[bool]
    rtp_rtsp_tcp: NotRequired[bool]
    rtp_tcp: NotRequired[bool]


class MediaStreaming(BaseModel):
    non_aggregate_control: Optional[bool] = None

    rtp_multicast: Optional[bool] = None

    rtp_rtsp_tcp: Optional[bool] = None

    rtp_tcp: Optional[bool] = None
