"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class S7TypedDict(TypedDict):
    copyright: NotRequired[str]
    cpu_profile: NotRequired[str]
    firmware: NotRequired[str]
    hardware: NotRequired[str]
    location: NotRequired[str]
    memory_serial_number: NotRequired[str]
    module: NotRequired[str]
    module_id: NotRequired[str]
    module_type: NotRequired[str]
    oem_id: NotRequired[str]
    plant_id: NotRequired[str]
    reserved_for_os: NotRequired[str]
    serial_number: NotRequired[str]
    system: NotRequired[str]


class S7(BaseModel):
    copyright: Optional[str] = None

    cpu_profile: Optional[str] = None

    firmware: Optional[str] = None

    hardware: Optional[str] = None

    location: Optional[str] = None

    memory_serial_number: Optional[str] = None

    module: Optional[str] = None

    module_id: Optional[str] = None

    module_type: Optional[str] = None

    oem_id: Optional[str] = None

    plant_id: Optional[str] = None

    reserved_for_os: Optional[str] = None

    serial_number: Optional[str] = None

    system: Optional[str] = None
