"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpenvpnTypedDict(TypedDict):
    accepts_v1: NotRequired[bool]
    accepts_v2: NotRequired[bool]


class Openvpn(BaseModel):
    accepts_v1: Optional[bool] = None

    accepts_v2: Optional[bool] = None
