"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DvrIPPartitionCapabilityTypedDict(TypedDict):
    max_partition_number: NotRequired[int]
    supported: NotRequired[bool]


class DvrIPPartitionCapability(BaseModel):
    max_partition_number: Optional[int] = None

    supported: Optional[bool] = None
