"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EvidenceTypedDict(TypedDict):
    data_path: NotRequired[str]
    exists: NotRequired[bool]
    found_value: NotRequired[str]
    literal_match: NotRequired[str]
    negative: NotRequired[bool]
    proprietary: NotRequired[bool]
    regex: NotRequired[str]
    semver_expression: NotRequired[str]


class Evidence(BaseModel):
    data_path: Optional[str] = None

    exists: Optional[bool] = None

    found_value: Optional[str] = None

    literal_match: Optional[str] = None

    negative: Optional[bool] = None

    proprietary: Optional[bool] = None

    regex: Optional[str] = None

    semver_expression: Optional[str] = None
