"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OtherNameTypedDict(TypedDict):
    id: NotRequired[str]
    r"""The OID identifying the syntax of the otherName value."""
    value: NotRequired[str]
    r"""The raw otherName value."""


class OtherName(BaseModel):
    id: Optional[str] = None
    r"""The OID identifying the syntax of the otherName value."""

    value: Optional[str] = None
    r"""The raw otherName value."""
