"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MurmurMurmurVersionTypedDict(TypedDict):
    build: NotRequired[int]
    major: NotRequired[int]
    minor: NotRequired[int]
    os: NotRequired[str]
    os_version: NotRequired[str]
    version_string: NotRequired[str]


class MurmurMurmurVersion(BaseModel):
    build: Optional[int] = None

    major: Optional[int] = None

    minor: Optional[int] = None

    os: Optional[str] = None

    os_version: Optional[str] = None

    version_string: Optional[str] = None
