"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rdp_domainparameters import RdpDomainParameters, RdpDomainParametersTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpConnectResponseTypedDict(TypedDict):
    connect_id: NotRequired[int]
    domain_parameters: NotRequired[RdpDomainParametersTypedDict]


class RdpConnectResponse(BaseModel):
    connect_id: Optional[int] = None

    domain_parameters: Optional[RdpDomainParameters] = None
