"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusResponsePrometheusVersionTypedDict(TypedDict):
    go_version: NotRequired[str]
    r"""Version of Go used to build Prometheus."""
    revision: NotRequired[str]
    r"""Revision of Prometheus."""
    version: NotRequired[str]
    r"""Version of Prometheus."""


class PrometheusResponsePrometheusVersion(BaseModel):
    go_version: Optional[str] = None
    r"""Version of Go used to build Prometheus."""

    revision: Optional[str] = None
    r"""Revision of Prometheus."""

    version: Optional[str] = None
    r"""Version of Prometheus."""
