"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FoxTypedDict(TypedDict):
    app_name: NotRequired[str]
    app_version: NotRequired[str]
    auth_agent_type: NotRequired[str]
    brand_id: NotRequired[str]
    host_address: NotRequired[str]
    host_id: NotRequired[str]
    hostname: NotRequired[str]
    id: NotRequired[int]
    language: NotRequired[str]
    os_name: NotRequired[str]
    os_version: NotRequired[str]
    station_name: NotRequired[str]
    sys_info: NotRequired[str]
    time_zone: NotRequired[str]
    version: NotRequired[str]
    vm_name: NotRequired[str]
    vm_uuid: NotRequired[str]
    vm_version: NotRequired[str]


class Fox(BaseModel):
    app_name: Optional[str] = None

    app_version: Optional[str] = None

    auth_agent_type: Optional[str] = None

    brand_id: Optional[str] = None

    host_address: Optional[str] = None

    host_id: Optional[str] = None

    hostname: Optional[str] = None

    id: Optional[int] = None

    language: Optional[str] = None

    os_name: Optional[str] = None

    os_version: Optional[str] = None

    station_name: Optional[str] = None

    sys_info: Optional[str] = None

    time_zone: Optional[str] = None

    version: Optional[str] = None

    vm_name: Optional[str] = None

    vm_uuid: Optional[str] = None

    vm_version: Optional[str] = None
