"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ciscoipsla_handshake import CiscoIpslaHandshake, CiscoIpslaHandshakeTypedDict
from .ciscoipsla_measureresponse import (
    CiscoIpslaMeasureResponse,
    CiscoIpslaMeasureResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaTypedDict(TypedDict):
    handshake: NotRequired[CiscoIpslaHandshakeTypedDict]
    measure_response: NotRequired[CiscoIpslaMeasureResponseTypedDict]


class CiscoIpsla(BaseModel):
    handshake: Optional[CiscoIpslaHandshake] = None

    measure_response: Optional[CiscoIpslaMeasureResponse] = None
