"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ModbusExceptionResponseTypedDict(TypedDict):
    exception_function: NotRequired[int]
    exception_type: NotRequired[int]


class ModbusExceptionResponse(BaseModel):
    exception_function: Optional[int] = None

    exception_type: Optional[int] = None
