"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PcAnywhereStatusTypedDict(TypedDict):
    in_use: NotRequired[bool]
    r"""Workstation is In Use if true, Available if false"""
    raw: NotRequired[str]
    r"""Full 'ST' query response"""


class PcAnywhereStatus(BaseModel):
    in_use: Optional[bool] = None
    r"""Workstation is In Use if true, Available if false"""

    raw: Optional[str] = None
    r"""Full 'ST' query response"""
