"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpSecurityProtocolTypedDict(TypedDict):
    credssp: NotRequired[bool]
    credssp_early_auth: NotRequired[bool]
    error: NotRequired[bool]
    error_bad_flags: NotRequired[bool]
    error_hybrid_required: NotRequired[bool]
    error_ssl_cert_missing: NotRequired[bool]
    error_ssl_forbidden: NotRequired[bool]
    error_ssl_required: NotRequired[bool]
    error_ssl_user_auth_required: NotRequired[bool]
    error_unknown: NotRequired[bool]
    raw_value: NotRequired[int]
    rdstls: NotRequired[bool]
    standard_rdp: NotRequired[bool]
    tls: NotRequired[bool]


class RdpSecurityProtocol(BaseModel):
    credssp: Optional[bool] = None

    credssp_early_auth: Optional[bool] = None

    error: Optional[bool] = None

    error_bad_flags: Optional[bool] = None

    error_hybrid_required: Optional[bool] = None

    error_ssl_cert_missing: Optional[bool] = None

    error_ssl_forbidden: Optional[bool] = None

    error_ssl_required: Optional[bool] = None

    error_ssl_user_auth_required: Optional[bool] = None

    error_unknown: Optional[bool] = None

    raw_value: Optional[int] = None

    rdstls: Optional[bool] = None

    standard_rdp: Optional[bool] = None

    tls: Optional[bool] = None
