"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TibiaTypedDict(TypedDict):
    client_version: NotRequired[str]
    location: NotRequired[str]
    login_ip: NotRequired[str]
    login_port: NotRequired[str]
    name: NotRequired[str]
    server: NotRequired[str]
    url: NotRequired[str]
    version: NotRequired[str]


class Tibia(BaseModel):
    client_version: Optional[str] = None

    location: Optional[str] = None

    login_ip: Optional[str] = None

    login_port: Optional[str] = None

    name: Optional[str] = None

    server: Optional[str] = None

    url: Optional[str] = None

    version: Optional[str] = None
