"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CabfOrganizationIDTypedDict(TypedDict):
    country: NotRequired[str]
    reference: NotRequired[str]
    scheme: NotRequired[str]
    state: NotRequired[str]


class CabfOrganizationID(BaseModel):
    country: Optional[str] = None

    reference: Optional[str] = None

    scheme: Optional[str] = None

    state: Optional[str] = None
