"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .monerop2p_payload import MoneroP2PPayload, MoneroP2PPayloadTypedDict
from .monerop2p_responseheader import (
    MoneroP2PResponseHeader,
    MoneroP2PResponseHeaderTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MoneroP2PPingResponseTypedDict(TypedDict):
    payload: NotRequired[MoneroP2PPayloadTypedDict]
    response_header: NotRequired[MoneroP2PResponseHeaderTypedDict]


class MoneroP2PPingResponse(BaseModel):
    payload: Optional[MoneroP2PPayload] = None

    response_header: Optional[MoneroP2PResponseHeader] = None
