"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RloginTypedDict(TypedDict):
    error: NotRequired[str]
    operating_system: NotRequired[str]
    software: NotRequired[str]
    software_version: NotRequired[str]


class Rlogin(BaseModel):
    error: Optional[str] = None

    operating_system: Optional[str] = None

    software: Optional[str] = None

    software_version: Optional[str] = None
