"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SearchCapabilitiesTypedDict(TypedDict):
    general_start_events: NotRequired[bool]
    metadata_search: NotRequired[bool]


class SearchCapabilities(BaseModel):
    general_start_events: Optional[bool] = None

    metadata_search: Optional[bool] = None
