"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class BacnetTypedDict(TypedDict):
    application_software_revision: NotRequired[str]
    description: NotRequired[str]
    firmware_revision: NotRequired[str]
    instance_number: NotRequired[int]
    location: NotRequired[str]
    model_name: NotRequired[str]
    object_name: NotRequired[str]
    vendor_id: NotRequired[int]
    vendor_name: NotRequired[str]


class Bacnet(BaseModel):
    application_software_revision: Optional[str] = None

    description: Optional[str] = None

    firmware_revision: Optional[str] = None

    instance_number: Optional[int] = None

    location: Optional[str] = None

    model_name: Optional[str] = None

    object_name: Optional[str] = None

    vendor_id: Optional[int] = None

    vendor_name: Optional[str] = None
