"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EipServiceTypedDict(TypedDict):
    capabilities: NotRequired[int]
    service_name: NotRequired[str]
    supports_tcp: NotRequired[bool]
    supports_udp: NotRequired[bool]


class EipService(BaseModel):
    capabilities: Optional[int] = None

    service_name: Optional[str] = None

    supports_tcp: Optional[bool] = None

    supports_udp: Optional[bool] = None
