"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class NetworkCapabilitiesTypedDict(TypedDict):
    dhcp_v6: NotRequired[bool]
    dot11_configuration: NotRequired[bool]
    dot1x_configurations: NotRequired[int]
    dynamic_dns: NotRequired[bool]
    hostname_from_dhcp: NotRequired[bool]
    ip_filter: NotRequired[bool]
    ipv6: NotRequired[bool]
    ntp: NotRequired[int]
    zero_configuration: NotRequired[bool]


class NetworkCapabilities(BaseModel):
    dhcp_v6: Optional[bool] = None

    dot11_configuration: Optional[bool] = None

    dot1x_configurations: Optional[int] = None

    dynamic_dns: Optional[bool] = None

    hostname_from_dhcp: Optional[bool] = None

    ip_filter: Optional[bool] = None

    ipv6: Optional[bool] = None

    ntp: Optional[int] = None

    zero_configuration: Optional[bool] = None
