"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class ConvertQueryErrorTypedDict(TypedDict):
    message: str
    r"""The error message if the query could not be converted."""


class ConvertQueryError(BaseModel):
    message: str
    r"""The error message if the query could not be converted."""
