"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ProfinetCmTypedDict(TypedDict):
    byte_order: NotRequired[str]
    lookup_response_raw: NotRequired[str]
    multiple_fragments: NotRequired[bool]


class ProfinetCm(BaseModel):
    byte_order: Optional[str] = None

    lookup_response_raw: Optional[str] = None

    multiple_fragments: Optional[bool] = None
