"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .eventassetchange import EventAssetChange, EventAssetChangeTypedDict
from .eventstatuschange import EventStatusChange, EventStatusChangeTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CollectionEventTypedDict(TypedDict):
    asset_change: NotRequired[EventAssetChangeTypedDict]
    status_change: NotRequired[EventStatusChangeTypedDict]


class CollectionEvent(BaseModel):
    asset_change: Optional[EventAssetChange] = None

    status_change: Optional[EventStatusChange] = None
