"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .smb_headerlog import SmbHeaderLog, SmbHeaderLogTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbSessionSetupLogTypedDict(TypedDict):
    header_log: NotRequired[SmbHeaderLogTypedDict]
    negotiate_flags: NotRequired[int]
    setup_flags: NotRequired[int]
    target_name: NotRequired[str]


class SmbSessionSetupLog(BaseModel):
    header_log: Optional[SmbHeaderLog] = None

    negotiate_flags: Optional[int] = None

    setup_flags: Optional[int] = None

    target_name: Optional[str] = None
