"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FieldDiffTypedDict(TypedDict):
    new: NotRequired[str]
    old: NotRequired[str]


class FieldDiff(BaseModel):
    new: Optional[str] = None

    old: Optional[str] = None
