"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DeviceIOCapabilitiesTypedDict(TypedDict):
    audio_outputs: NotRequired[int]
    audio_sources: NotRequired[int]
    digital_inputs: NotRequired[int]
    relay_outputs: NotRequired[int]
    serial_ports: NotRequired[int]
    video_outputs: NotRequired[int]
    video_source: NotRequired[int]


class DeviceIOCapabilities(BaseModel):
    audio_outputs: Optional[int] = None

    audio_sources: Optional[int] = None

    digital_inputs: Optional[int] = None

    relay_outputs: Optional[int] = None

    serial_ports: Optional[int] = None

    video_outputs: Optional[int] = None

    video_source: Optional[int] = None
