"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RippleClioResultsTypedDict(TypedDict):
    clio_version: NotRequired[str]
    rippled_version: NotRequired[str]
    validated: NotRequired[bool]
    validation_quorum: NotRequired[int]


class RippleClioResults(BaseModel):
    clio_version: Optional[str] = None

    rippled_version: Optional[str] = None

    validated: Optional[bool] = None

    validation_quorum: Optional[int] = None
