"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpProtocolFlagsTypedDict(TypedDict):
    dynvc_graphics_pipeline: NotRequired[bool]
    extended_client_data_supported: NotRequired[bool]
    neg_resp_reserved: NotRequired[bool]
    restricted_admin_mode: NotRequired[bool]
    restricted_auth_mode: NotRequired[bool]


class RdpProtocolFlags(BaseModel):
    dynvc_graphics_pipeline: Optional[bool] = None

    extended_client_data_supported: Optional[bool] = None

    neg_resp_reserved: Optional[bool] = None

    restricted_admin_mode: Optional[bool] = None

    restricted_auth_mode: Optional[bool] = None
