"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ReplayCapabilitiesTypedDict(TypedDict):
    reverse_playback: NotRequired[bool]
    rtp_rtsp_tcp: NotRequired[bool]
    session_timeout_range: NotRequired[str]


class ReplayCapabilities(BaseModel):
    reverse_playback: Optional[bool] = None

    rtp_rtsp_tcp: Optional[bool] = None

    session_timeout_range: Optional[str] = None
