"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ciscoipsla_handshake_header import (
    CiscoIpslaHandshakeHeader,
    CiscoIpslaHandshakeHeaderTypedDict,
)
from .ciscoipsla_handshake_message import (
    CiscoIpslaHandshakeMessage,
    CiscoIpslaHandshakeMessageTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaHandshakeTypedDict(TypedDict):
    header: NotRequired[CiscoIpslaHandshakeHeaderTypedDict]
    message: NotRequired[CiscoIpslaHandshakeMessageTypedDict]


class CiscoIpslaHandshake(BaseModel):
    header: Optional[CiscoIpslaHandshakeHeader] = None

    message: Optional[CiscoIpslaHandshakeMessage] = None
