"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataThreadPoolTypedDict(TypedDict):
    keep_alive: NotRequired[str]
    max: NotRequired[int]
    min: NotRequired[int]
    queue_size: NotRequired[int]
    type: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataThreadPool(BaseModel):
    keep_alive: Optional[str] = None

    max: Optional[int] = None

    min: Optional[int] = None

    queue_size: Optional[int] = None

    type: Optional[str] = None
