"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesEndpointSubsetPortTypedDict(TypedDict):
    name: NotRequired[str]
    port: NotRequired[int]
    protocol: NotRequired[str]


class KubernetesEndpointSubsetPort(BaseModel):
    name: Optional[str] = None

    port: Optional[int] = None

    protocol: Optional[str] = None
