"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpcUaUserTokenPolicyTypedDict(TypedDict):
    issued_token_type: NotRequired[str]
    issuer_endpoint_url: NotRequired[str]
    policy_id: NotRequired[str]
    security_policy_uri: NotRequired[str]
    token_type: NotRequired[int]


class OpcUaUserTokenPolicy(BaseModel):
    issued_token_type: Optional[str] = None

    issuer_endpoint_url: Optional[str] = None

    policy_id: Optional[str] = None

    security_policy_uri: Optional[str] = None

    token_type: Optional[int] = None
