"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SignedCertificateTimestampSignatureTypedDict(TypedDict):
    hash_algorithm: NotRequired[str]
    signature: NotRequired[str]
    signature_algorithm: NotRequired[str]


class SignedCertificateTimestampSignature(BaseModel):
    hash_algorithm: Optional[str] = None

    signature: Optional[str] = None

    signature_algorithm: Optional[str] = None
