"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ForwardDNSResolvedTypedDict(TypedDict):
    name: NotRequired[str]
    resolve_time: NotRequired[str]


class ForwardDNSResolved(BaseModel):
    name: Optional[str] = None

    resolve_time: Optional[str] = None
