"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .etcd_v2 import EtcdV2, EtcdV2TypedDict
from .etcd_v3 import EtcdV3, EtcdV3TypedDict
from .etcd_version import EtcdVersion, EtcdVersionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EtcdTypedDict(TypedDict):
    v2: NotRequired[EtcdV2TypedDict]
    v3: NotRequired[EtcdV3TypedDict]
    version: NotRequired[EtcdVersionTypedDict]


class Etcd(BaseModel):
    v2: Optional[EtcdV2] = None

    v3: Optional[EtcdV3] = None

    version: Optional[EtcdVersion] = None
