"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata_nodesettings_node_attr_ml import (
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrML,
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrMLTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrTypedDict(TypedDict):
    ml: NotRequired[
        ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrMLTypedDict
    ]
    xpack_installed: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttr(BaseModel):
    ml: Optional[ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrML] = None

    xpack_installed: Optional[str] = None
