"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class RealportTypedDict(TypedDict):
    hardware_id: NotRequired[int]
    hardware_version: NotRequired[int]
    num_ports: NotRequired[int]
    product_name: NotRequired[str]
    software_version: NotRequired[int]
    unpatched_etherlite: NotRequired[bool]
    vpd: NotRequired[Dict[str, str]]


class Realport(BaseModel):
    hardware_id: Optional[int] = None

    hardware_version: Optional[int] = None

    num_ports: Optional[int] = None

    product_name: Optional[str] = None

    software_version: Optional[int] = None

    unpatched_etherlite: Optional[bool] = None

    vpd: Optional[Dict[str, str]] = None
