"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SevenDaysToDieTypedDict(TypedDict):
    game_name: NotRequired[str]
    game_type: NotRequired[str]
    region: NotRequired[str]
    server_url: NotRequired[str]
    server_version: NotRequired[str]
    steam_id: NotRequired[str]
    version: NotRequired[str]


class SevenDaysToDie(BaseModel):
    game_name: Optional[str] = None

    game_type: Optional[str] = None

    region: Optional[str] = None

    server_url: Optional[str] = None

    server_version: Optional[str] = None

    steam_id: Optional[str] = None

    version: Optional[str] = None
