"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class X11TypedDict(TypedDict):
    refusal_reason: NotRequired[str]
    requires_authentication: NotRequired[bool]
    vendor: NotRequired[str]
    version: NotRequired[str]


class X11(BaseModel):
    refusal_reason: Optional[str] = None

    requires_authentication: Optional[bool] = None

    vendor: Optional[str] = None

    version: Optional[str] = None
