"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class SearchAggregateResponseBucketTypedDict(TypedDict):
    count: int
    key: str


class SearchAggregateResponseBucket(BaseModel):
    count: int

    key: str
