"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ct_record import CtRecord, CtRecordTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class CtTypedDict(TypedDict):
    entries: NotRequired[Dict[str, CtRecordTypedDict]]


class Ct(BaseModel):
    entries: Optional[Dict[str, CtRecord]] = None
