"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaHandshakeMessageTypedDict(TypedDict):
    ip: NotRequired[str]
    length: NotRequired[int]
    port: NotRequired[int]
    type: NotRequired[int]


class CiscoIpslaHandshakeMessage(BaseModel):
    ip: Optional[str] = None

    length: Optional[int] = None

    port: Optional[int] = None

    type: Optional[int] = None
