"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EcdsaPublicKeyTypedDict(TypedDict):
    b: NotRequired[str]
    curve: NotRequired[str]
    gx: NotRequired[str]
    gy: NotRequired[str]
    length: NotRequired[int]
    n: NotRequired[str]
    p: NotRequired[str]
    pub: NotRequired[str]
    x: NotRequired[str]
    y: NotRequired[str]


class EcdsaPublicKey(BaseModel):
    b: Optional[str] = None

    curve: Optional[str] = None

    gx: Optional[str] = None

    gy: Optional[str] = None

    length: Optional[int] = None

    n: Optional[str] = None

    p: Optional[str] = None

    pub: Optional[str] = None

    x: Optional[str] = None

    y: Optional[str] = None
