"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SnmpPhysicalTypedDict(TypedDict):
    firmware_rev: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.9 - Firmware revision string"""
    hardware_rev: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.8 - Hardware revision string"""
    mfg_name: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.12 - Name of mfg"""
    model_name: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.13 - Model name of component"""
    name: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.7 - Entity name"""
    serial_num: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.11 - Serial number string"""
    software_rev: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.10 - Software revision string"""


class SnmpPhysical(BaseModel):
    firmware_rev: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.9 - Firmware revision string"""

    hardware_rev: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.8 - Hardware revision string"""

    mfg_name: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.12 - Name of mfg"""

    model_name: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.13 - Model name of component"""

    name: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.7 - Entity name"""

    serial_num: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.11 - Serial number string"""

    software_rev: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.10 - Software revision string"""
