"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SnmpInterfacesTypedDict(TypedDict):
    num_ifaces: NotRequired[int]
    r"""1.3.6.1.2.1.2.1 - Number of network interfaces"""


class SnmpInterfaces(BaseModel):
    num_ifaces: Optional[int] = None
    r"""1.3.6.1.2.1.2.1 - Number of network interfaces"""
