"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStoreTypedDict(TypedDict):
    reserved_in_bytes: NotRequired[int]
    size_in_bytes: NotRequired[int]


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStore(BaseModel):
    reserved_in_bytes: Optional[int] = None

    size_in_bytes: Optional[int] = None
