"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WeblogicT3TypedDict(TypedDict):
    error: NotRequired[str]
    error_message: NotRequired[str]
    weblogic_version: NotRequired[str]


class WeblogicT3(BaseModel):
    error: Optional[str] = None

    error_message: Optional[str] = None

    weblogic_version: Optional[str] = None
