"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PgbouncerStartupCapabilitiesTypedDict(TypedDict):
    v2: NotRequired[bool]
    v3: NotRequired[bool]
    v4: NotRequired[bool]


class PgbouncerStartupCapabilities(BaseModel):
    v2: Optional[bool] = None

    v3: Optional[bool] = None

    v4: Optional[bool] = None
