"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ventrilo_header import VentriloHeader, VentriloHeaderTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class VentriloMessageTypedDict(TypedDict):
    body: NotRequired[str]
    error: NotRequired[str]
    header: NotRequired[VentriloHeaderTypedDict]


class VentriloMessage(BaseModel):
    body: Optional[str] = None

    error: Optional[str] = None

    header: Optional[VentriloHeader] = None
