"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class HikvisionPlatformLibraryTypedDict(TypedDict):
    name: NotRequired[str]
    version: NotRequired[str]


class HikvisionPlatformLibrary(BaseModel):
    name: Optional[str] = None

    version: Optional[str] = None
