"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DsaPublicKeyTypedDict(TypedDict):
    g: NotRequired[str]
    p: NotRequired[str]
    q: NotRequired[str]
    y: NotRequired[str]


class DsaPublicKey(BaseModel):
    g: Optional[str] = None

    p: Optional[str] = None

    q: Optional[str] = None

    y: Optional[str] = None
