"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ed25519CryptographicKeyTypedDict(TypedDict):
    public_bytes: NotRequired[str]


class Ed25519CryptographicKey(BaseModel):
    public_bytes: Optional[str] = None
