"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocsTypedDict(TypedDict):
    count: NotRequired[int]
    deleted: NotRequired[int]


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocs(BaseModel):
    count: Optional[int] = None

    deleted: Optional[int] = None
