"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mssql_preloginoptions import MssqlPreloginOptions, MssqlPreloginOptionsTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MssqlTypedDict(TypedDict):
    encrypt_mode: NotRequired[str]
    r"""The negotiated ENCRYPT_MODE with the server"""
    instance_name: NotRequired[str]
    prelogin_options: NotRequired[MssqlPreloginOptionsTypedDict]
    version: NotRequired[str]


class Mssql(BaseModel):
    encrypt_mode: Optional[str] = None
    r"""The negotiated ENCRYPT_MODE with the server"""

    instance_name: Optional[str] = None

    prelogin_options: Optional[MssqlPreloginOptions] = None

    version: Optional[str] = None
