"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiCommandPayloadCommandNumberTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The human-readable name of the cmd + NetFn"""
    raw: NotRequired[int]
    r"""The raw value of the cmd value"""


class IpmiCommandPayloadCommandNumber(BaseModel):
    name: Optional[str] = None
    r"""The human-readable name of the cmd + NetFn"""

    raw: Optional[int] = None
    r"""The raw value of the cmd value"""
