"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrMLTypedDict(
    TypedDict
):
    enabled: NotRequired[str]
    machine_memory: NotRequired[str]
    max_open_jobs: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrML(BaseModel):
    enabled: Optional[str] = None

    machine_memory: Optional[str] = None

    max_open_jobs: Optional[str] = None
