"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RsaPublicKeyTypedDict(TypedDict):
    exponent: NotRequired[int]
    r"""The RSA key's public exponent (e)."""
    length: NotRequired[int]
    r"""Bit-length of the RSA modulus."""
    modulus: NotRequired[str]
    r"""The RSA key's modulus (n) in big-endian encoding."""


class RsaPublicKey(BaseModel):
    exponent: Optional[int] = None
    r"""The RSA key's public exponent (e)."""

    length: Optional[int] = None
    r"""Bit-length of the RSA modulus."""

    modulus: Optional[str] = None
    r"""The RSA key's modulus (n) in big-endian encoding."""
