"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TrackedScanTaskStatus(str, Enum):
    UNKNOWN = ""
    SCANNING = "scanning"
    SCANNED = "scanned"
    REJECTED = "rejected"
    TIMED_OUT = "timed_out"
    COMPLETED = "completed"
    IGNORED = "ignored"


class TrackedScanTaskTypedDict(TypedDict):
    description: NotRequired[str]
    status: NotRequired[TrackedScanTaskStatus]
    update_time: NotRequired[str]


class TrackedScanTask(BaseModel):
    description: Optional[str] = None

    status: Optional[TrackedScanTaskStatus] = None

    update_time: Optional[str] = None
