"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesVersionInfoTypedDict(TypedDict):
    build_date: NotRequired[str]
    r"""Date version was built."""
    compiler: NotRequired[str]
    r"""Go Compiler used"""
    git_commit: NotRequired[str]
    r"""Git commit version built from."""
    git_tree_state: NotRequired[str]
    r"""State of the tree when built."""
    git_version: NotRequired[str]
    go_version: NotRequired[str]
    r"""Version of GO used to build version."""
    major: NotRequired[str]
    r"""Kubernetes major version"""
    minor: NotRequired[str]
    r"""Kubernetes minor version"""
    platform: NotRequired[str]
    r"""Platform compiled for"""


class KubernetesVersionInfo(BaseModel):
    build_date: Optional[str] = None
    r"""Date version was built."""

    compiler: Optional[str] = None
    r"""Go Compiler used"""

    git_commit: Optional[str] = None
    r"""Git commit version built from."""

    git_tree_state: Optional[str] = None
    r"""State of the tree when built."""

    git_version: Optional[str] = None

    go_version: Optional[str] = None
    r"""Version of GO used to build version."""

    major: Optional[str] = None
    r"""Kubernetes major version"""

    minor: Optional[str] = None
    r"""Kubernetes minor version"""

    platform: Optional[str] = None
    r"""Platform compiled for"""
