"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RecordType(str, Enum):
    UNKNOWN = ""
    A = "a"
    AAAA = "aaaa"


class HostDNSForwardResolutionTypedDict(TypedDict):
    name: NotRequired[str]
    record_type: NotRequired[RecordType]
    resolve_time: NotRequired[str]
    server: NotRequired[str]


class HostDNSForwardResolution(BaseModel):
    name: Optional[str] = None

    record_type: Optional[RecordType] = None

    resolve_time: Optional[str] = None

    server: Optional[str] = None
