"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class HidVertxTypedDict(TypedDict):
    firmware_date: NotRequired[str]
    id: NotRequired[str]
    ip: NotRequired[str]
    mac_address: NotRequired[str]
    make_model: NotRequired[str]
    model: NotRequired[str]
    version: NotRequired[str]


class HidVertx(BaseModel):
    firmware_date: Optional[str] = None

    id: Optional[str] = None

    ip: Optional[str] = None

    mac_address: Optional[str] = None

    make_model: Optional[str] = None

    model: Optional[str] = None

    version: Optional[str] = None
