"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PptpResponseInfoTypedDict(TypedDict):
    code: NotRequired[int]
    meaning: NotRequired[str]


class PptpResponseInfo(BaseModel):
    code: Optional[int] = None

    meaning: Optional[str] = None
