"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ike_v1 import IkeV1, IkeV1TypedDict
from .ike_v2 import IkeV2, IkeV2TypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IkeTypedDict(TypedDict):
    v1: NotRequired[IkeV1TypedDict]
    v2: NotRequired[IkeV2TypedDict]


class Ike(BaseModel):
    v1: Optional[IkeV1] = None

    v2: Optional[IkeV2] = None
