"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MinecraftTypedDict(TypedDict):
    motd: NotRequired[str]
    players_max: NotRequired[int]
    players_online: NotRequired[int]
    protocol_version: NotRequired[str]
    server_version: NotRequired[str]


class Minecraft(BaseModel):
    motd: Optional[str] = None

    players_max: Optional[int] = None

    players_online: Optional[int] = None

    protocol_version: Optional[str] = None

    server_version: Optional[str] = None
