"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class NtlmInfoTypedDict(TypedDict):
    always_sign_supported: NotRequired[bool]
    challenge_type: NotRequired[int]
    dns_domain_name: NotRequired[str]
    dns_server_name: NotRequired[str]
    dns_tree_name: NotRequired[str]
    encryption_128bit_supported: NotRequired[bool]
    encryption_56bit_supported: NotRequired[bool]
    netbios_computer_name: NotRequired[str]
    netbios_domain_name: NotRequired[str]
    ntlm1_supported: NotRequired[bool]
    ntlm2_supported: NotRequired[bool]
    ntlm_version: NotRequired[int]
    os_version: NotRequired[str]
    target_name: NotRequired[str]


class NtlmInfo(BaseModel):
    always_sign_supported: Optional[bool] = None

    challenge_type: Optional[int] = None

    dns_domain_name: Optional[str] = None

    dns_server_name: Optional[str] = None

    dns_tree_name: Optional[str] = None

    encryption_128bit_supported: Optional[bool] = None

    encryption_56bit_supported: Optional[bool] = None

    netbios_computer_name: Optional[str] = None

    netbios_domain_name: Optional[str] = None

    ntlm1_supported: Optional[bool] = None

    ntlm2_supported: Optional[bool] = None

    ntlm_version: Optional[int] = None

    os_version: Optional[str] = None

    target_name: Optional[str] = None
