"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificateasset import CertificateAsset, CertificateAssetTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeCertificateAssetTypedDict(TypedDict):
    result: NotRequired[CertificateAssetTypedDict]


class ResponseEnvelopeCertificateAsset(BaseModel):
    result: Optional[CertificateAsset] = None
