"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpDomainParametersTypedDict(TypedDict):
    domain_protocol_version: NotRequired[int]
    max_channel_ids: NotRequired[int]
    max_mcspdu_size: NotRequired[int]
    max_provider_height: NotRequired[int]
    max_token_ids: NotRequired[int]
    max_user_id_channels: NotRequired[int]
    min_throughput: NotRequired[int]
    num_priorities: NotRequired[int]


class RdpDomainParameters(BaseModel):
    domain_protocol_version: Optional[int] = None

    max_channel_ids: Optional[int] = None

    max_mcspdu_size: Optional[int] = None

    max_provider_height: Optional[int] = None

    max_token_ids: Optional[int] = None

    max_user_id_channels: Optional[int] = None

    min_throughput: Optional[int] = None

    num_priorities: Optional[int] = None
