"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikeHTTPConfigTypedDict(TypedDict):
    client: NotRequired[str]
    uri: NotRequired[str]
    verb: NotRequired[str]


class CobaltStrikeHTTPConfig(BaseModel):
    client: Optional[str] = None

    uri: Optional[str] = None

    verb: Optional[str] = None
