"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FloatValueTypedDict(TypedDict):
    value: NotRequired[float]


class FloatValue(BaseModel):
    value: Optional[float] = None
