"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dhcpdiscover_responseparams import (
    DhcpdiscoverResponseParams,
    DhcpdiscoverResponseParamsTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DhcpdiscoverTypedDict(TypedDict):
    method: NotRequired[str]
    params: NotRequired[DhcpdiscoverResponseParamsTypedDict]


class Dhcpdiscover(BaseModel):
    method: Optional[str] = None

    params: Optional[DhcpdiscoverResponseParams] = None
