"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .network import Network, NetworkTypedDict
from .organization import Organization, OrganizationTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WhoisTypedDict(TypedDict):
    network: NotRequired[NetworkTypedDict]
    organization: NotRequired[OrganizationTypedDict]


class Whois(BaseModel):
    network: Optional[Network] = None

    organization: Optional[Organization] = None
