"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rocketmq_responseheader import (
    RocketmqResponseHeader,
    RocketmqResponseHeaderTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RocketmqClusterInfoTypedDict(TypedDict):
    header: NotRequired[RocketmqResponseHeaderTypedDict]
    payload: NotRequired[str]


class RocketmqClusterInfo(BaseModel):
    header: Optional[RocketmqResponseHeader] = None

    payload: Optional[str] = None
