"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .searchaggregateresponse import (
    SearchAggregateResponse,
    SearchAggregateResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeSearchAggregateResponseTypedDict(TypedDict):
    result: NotRequired[SearchAggregateResponseTypedDict]


class ResponseEnvelopeSearchAggregateResponse(BaseModel):
    result: Optional[SearchAggregateResponse] = None
