"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectioneventsresponse import (
    CollectionEventsResponse,
    CollectionEventsResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeCollectionEventsResponseTypedDict(TypedDict):
    result: NotRequired[CollectionEventsResponseTypedDict]


class ResponseEnvelopeCollectionEventsResponse(BaseModel):
    result: Optional[CollectionEventsResponse] = None
