"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ser2net_serialparameters import (
    Ser2NetSerialParameters,
    Ser2NetSerialParametersTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ser2NetTypedDict(TypedDict):
    device: NotRequired[str]
    os: NotRequired[str]
    serial_parameters: NotRequired[Ser2NetSerialParametersTypedDict]
    software: NotRequired[str]
    software_version: NotRequired[str]


class Ser2Net(BaseModel):
    device: Optional[str] = None

    os: Optional[str] = None

    serial_parameters: Optional[Ser2NetSerialParameters] = None

    software: Optional[str] = None

    software_version: Optional[str] = None
