"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ZeromqGreetingTypedDict(TypedDict):
    as_server: NotRequired[bool]
    mechanism: NotRequired[str]
    signature: NotRequired[str]
    version_major: NotRequired[int]
    version_minor: NotRequired[int]


class ZeromqGreeting(BaseModel):
    as_server: Optional[bool] = None

    mechanism: Optional[str] = None

    signature: Optional[str] = None

    version_major: Optional[int] = None

    version_minor: Optional[int] = None
