"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpVersionTypedDict(TypedDict):
    major: NotRequired[int]
    minor: NotRequired[int]
    raw: NotRequired[str]
    r"""Raw Version Response, Major version is stored in upper 2 bytes, minor in lower 2 bytes."""


class RdpVersion(BaseModel):
    major: Optional[int] = None

    minor: Optional[int] = None

    raw: Optional[str] = None
    r"""Raw Version Response, Major version is stored in upper 2 bytes, minor in lower 2 bytes."""
