"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchErrorMessageTypedDict(TypedDict):
    header: NotRequired[str]
    reason: NotRequired[str]
    type: NotRequired[str]


class ElasticSearchErrorMessage(BaseModel):
    header: Optional[str] = None

    reason: Optional[str] = None

    type: Optional[str] = None
