"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OracleDescriptorTypedDict(TypedDict):
    key: NotRequired[str]
    r"""The dot-delimited path to the parsed value from the error received when the initial handshake is refused."""
    value: NotRequired[str]
    r"""The parsed value from the error received when the initial handshake is refused."""


class OracleDescriptor(BaseModel):
    key: Optional[str] = None
    r"""The dot-delimited path to the parsed value from the error received when the initial handshake is refused."""

    value: Optional[str] = None
    r"""The parsed value from the error received when the initial handshake is refused."""
