"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .trackedscan import TrackedScan, TrackedScanTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeTrackedScanTypedDict(TypedDict):
    result: NotRequired[TrackedScanTypedDict]


class ResponseEnvelopeTrackedScan(BaseModel):
    result: Optional[TrackedScan] = None
