"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ScpiTypedDict(TypedDict):
    firmware: NotRequired[str]
    manufacturer: NotRequired[str]
    model: NotRequired[str]
    serial: NotRequired[str]


class Scpi(BaseModel):
    firmware: Optional[str] = None

    manufacturer: Optional[str] = None

    model: Optional[str] = None

    serial: Optional[str] = None
