"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IbmnjeTypedDict(TypedDict):
    ohost: NotRequired[str]
    oip: NotRequired[str]
    reason: NotRequired[int]
    rhost: NotRequired[str]
    rip: NotRequired[str]
    type: NotRequired[str]


class Ibmnje(BaseModel):
    ohost: Optional[str] = None

    oip: Optional[str] = None

    reason: Optional[int] = None

    rhost: Optional[str] = None

    rip: Optional[str] = None

    type: Optional[str] = None
