"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .monerop2p_pingresponse import (
    MoneroP2PPingResponse,
    MoneroP2PPingResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MoneroP2PTypedDict(TypedDict):
    ping_response: NotRequired[MoneroP2PPingResponseTypedDict]


class MoneroP2P(BaseModel):
    ping_response: Optional[MoneroP2PPingResponse] = None
