"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SSHEndpointIDTypedDict(TypedDict):
    comment: NotRequired[str]
    protocol_version: NotRequired[str]
    raw: NotRequired[str]
    software_version: NotRequired[str]


class SSHEndpointID(BaseModel):
    comment: Optional[str] = None

    protocol_version: Optional[str] = None

    raw: Optional[str] = None

    software_version: Optional[str] = None
