"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchSystemInfoVerTypedDict(TypedDict):
    build_date: NotRequired[str]
    build_flavor: NotRequired[str]
    build_hash: NotRequired[str]
    build_snapshot: NotRequired[bool]
    build_type: NotRequired[str]
    lucene_version: NotRequired[str]
    min_idx_compat_ver: NotRequired[str]
    min_wire_compat_ver: NotRequired[str]
    number: NotRequired[str]


class ElasticSearchSystemInfoVer(BaseModel):
    build_date: Optional[str] = None

    build_flavor: Optional[str] = None

    build_hash: Optional[str] = None

    build_snapshot: Optional[bool] = None

    build_type: Optional[str] = None

    lucene_version: Optional[str] = None

    min_idx_compat_ver: Optional[str] = None

    min_wire_compat_ver: Optional[str] = None

    number: Optional[str] = None
