"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SpiceTypedDict(TypedDict):
    major_version: NotRequired[int]
    minor_version: NotRequired[int]
    tls_only: NotRequired[bool]
    x509_public_key: NotRequired[str]


class Spice(BaseModel):
    major_version: Optional[int] = None

    minor_version: Optional[int] = None

    tls_only: Optional[bool] = None

    x509_public_key: Optional[str] = None
