"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .zeromq_greeting import ZeromqGreeting, ZeromqGreetingTypedDict
from .zeromq_handshake import ZeromqHandshake, ZeromqHandshakeTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ZeromqTypedDict(TypedDict):
    greeting: NotRequired[ZeromqGreetingTypedDict]
    handshake: NotRequired[ZeromqHandshakeTypedDict]
    subscription_data: NotRequired[str]
    subscription_match: NotRequired[Dict[str, bool]]


class Zeromq(BaseModel):
    greeting: Optional[ZeromqGreeting] = None

    handshake: Optional[ZeromqHandshake] = None

    subscription_data: Optional[str] = None

    subscription_match: Optional[Dict[str, bool]] = None
