"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_clustercombinedinfo_indices_docs import (
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocs,
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocsTypedDict,
)
from .elasticsearch_resultsnodeinfo_clustercombinedinfo_indices_store import (
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStore,
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStoreTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesTypedDict(TypedDict):
    count: NotRequired[int]
    docs: NotRequired[
        ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocsTypedDict
    ]
    store: NotRequired[
        ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStoreTypedDict
    ]


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndices(BaseModel):
    count: Optional[int] = None

    docs: Optional[ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocs] = None

    store: Optional[ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStore] = None
