"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MediaProfileTypedDict(TypedDict):
    max_profile_count: NotRequired[int]


class MediaProfile(BaseModel):
    max_profile_count: Optional[int] = None
