"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MmsTypedDict(TypedDict):
    model: NotRequired[str]
    revision: NotRequired[str]
    vendor: NotRequired[str]


class Mms(BaseModel):
    model: Optional[str] = None

    revision: Optional[str] = None

    vendor: Optional[str] = None
