"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GeneralSubtreeIPTypedDict(TypedDict):
    begin: NotRequired[str]
    r"""The first IP address in the range."""
    cidr: NotRequired[str]
    r"""The CIDR specifying the subtree."""
    end: NotRequired[str]
    r"""The last IP address in the range."""
    mask: NotRequired[str]
    r"""The subnet mask of the CIDR."""


class GeneralSubtreeIP(BaseModel):
    begin: Optional[str] = None
    r"""The first IP address in the range."""

    cidr: Optional[str] = None
    r"""The CIDR specifying the subtree."""

    end: Optional[str] = None
    r"""The last IP address in the range."""

    mask: Optional[str] = None
    r"""The subnet mask of the CIDR."""
